# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountPersonas(BaseModel):
    count_personas: Optional["CountPersonasCountPersonas"] = Field(
        alias="countPersonas"
    )


class CountPersonasCountPersonas(BaseModel):
    count: Optional[Any]


CountPersonas.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, FactCategory, ObservableTypes, SourceTypes


class GetFact(BaseModel):
    fact: Optional["GetFactFact"]


class GetFactFact(BaseModel):
    id: str
    creation_date: Any = Field(alias="creationDate")
    owner: "GetFactFactOwner"
    state: EntityState
    text: str
    valid_at: Optional[Any] = Field(alias="validAt")
    invalid_at: Optional[Any] = Field(alias="invalidAt")
    relevance: Optional[float]
    mentions: Optional[list[Optional["GetFactFactMentions"]]]
    assertions: Optional[list[Optional["GetFactFactAssertions"]]]
    feeds: Optional[list[Optional["GetFactFactFeeds"]]]
    content: Optional["GetFactFactContent"]
    conversation: Optional["GetFactFactConversation"]
    persona: Optional["GetFactFactPersona"]
    source_type: Optional[SourceTypes] = Field(alias="sourceType")
    category: Optional[FactCategory]
    confidence: Optional[float]


class GetFactFactOwner(BaseModel):
    id: str


class GetFactFactMentions(BaseModel):
    type: Optional[ObservableTypes]
    observable: Optional["GetFactFactMentionsObservable"]
    start: Optional[int]
    end: Optional[int]


class GetFactFactMentionsObservable(BaseModel):
    id: str
    name: Optional[str]


class GetFactFactAssertions(BaseModel):
    text: str
    mentions: Optional[list[Optional["GetFactFactAssertionsMentions"]]]


class GetFactFactAssertionsMentions(BaseModel):
    type: Optional[ObservableTypes]
    observable: Optional["GetFactFactAssertionsMentionsObservable"]
    start: Optional[int]
    end: Optional[int]


class GetFactFactAssertionsMentionsObservable(BaseModel):
    id: str
    name: Optional[str]


class GetFactFactFeeds(BaseModel):
    id: str
    name: str


class GetFactFactContent(BaseModel):
    id: str
    name: str


class GetFactFactConversation(BaseModel):
    id: str
    name: str


class GetFactFactPersona(BaseModel):
    id: str
    name: str


GetFact.model_rebuild()
GetFactFact.model_rebuild()
GetFactFactMentions.model_rebuild()
GetFactFactAssertions.model_rebuild()
GetFactFactAssertionsMentions.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class GetMedicalStudy(BaseModel):
    medical_study: Optional["GetMedicalStudyMedicalStudy"] = Field(alias="medicalStudy")


class GetMedicalStudyMedicalStudy(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetMedicalStudyMedicalStudyOwner"
    state: EntityState
    alternate_names: Optional[list[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[list[Optional["GetMedicalStudyMedicalStudyFeeds"]]]
    links: Optional[list[Optional["GetMedicalStudyMedicalStudyLinks"]]]
    workflow: Optional["GetMedicalStudyMedicalStudyWorkflow"]
    location: Optional["GetMedicalStudyMedicalStudyLocation"]
    h_3: Optional["GetMedicalStudyMedicalStudyH3"] = Field(alias="h3")
    address: Optional["GetMedicalStudyMedicalStudyAddress"]


class GetMedicalStudyMedicalStudyOwner(BaseModel):
    id: str


class GetMedicalStudyMedicalStudyFeeds(BaseModel):
    id: str
    name: str


class GetMedicalStudyMedicalStudyLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class GetMedicalStudyMedicalStudyWorkflow(BaseModel):
    id: str
    name: str


class GetMedicalStudyMedicalStudyLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class GetMedicalStudyMedicalStudyH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class GetMedicalStudyMedicalStudyAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


GetMedicalStudy.model_rebuild()
GetMedicalStudyMedicalStudy.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    AsanaAuthenticationTypes,
    AttioAuthenticationTypes,
    AttioFeedAuthenticationTypes,
    AttioIssueAuthenticationTypes,
    AttioMeetingAuthenticationTypes,
    BambooHRAuthenticationTypes,
    BlobListingTypes,
    BoxAuthenticationTypes,
    CalendarListingTypes,
    ConfluenceAuthenticationTypes,
    ConfluenceTypes,
    CrustdataWatcherSignalTypes,
    DropboxAuthenticationTypes,
    EmailListingTypes,
    EntityState,
    ExaSearchTypes,
    FeedListingTypes,
    FeedServiceTypes,
    FeedSyncMode,
    FeedTypes,
    GitHubAuthenticationTypes,
    GitHubCommitAuthenticationTypes,
    GitHubPullRequestAuthenticationTypes,
    GoogleCalendarAuthenticationTypes,
    GoogleContactsAuthenticationTypes,
    GoogleDriveAuthenticationTypes,
    GoogleEmailAuthenticationTypes,
    GustoAuthenticationTypes,
    HubSpotAuthenticationTypes,
    HubSpotFeedAuthenticationTypes,
    HubSpotIssueAuthenticationTypes,
    IntercomAuthenticationTypes,
    IntercomConversationsAuthenticationTypes,
    IntercomIssueAuthenticationTypes,
    JiraAuthenticationTypes,
    LinearAuthenticationTypes,
    LinkedInPostContentTypes,
    LinkedInPostListingTypes,
    MeetingContentTypes,
    MicrosoftCalendarAuthenticationTypes,
    MicrosoftContactsAuthenticationTypes,
    MicrosoftEmailAuthenticationTypes,
    MicrosoftTeamsAuthenticationTypes,
    NotionAuthenticationTypes,
    NotionTypes,
    OneDriveAuthenticationTypes,
    ParallelGenerators,
    ParallelProcessors,
    SalesforceAuthenticationTypes,
    SalesforceFeedAuthenticationTypes,
    SalesforceIssueAuthenticationTypes,
    SearchServiceTypes,
    SharePointAuthenticationTypes,
    SiteTypes,
    SlackAuthenticationTypes,
    TimedPolicyRecurrenceTypes,
    TrelloTypes,
    TwitterAuthenticationTypes,
    TwitterListingTypes,
    YouTubeTypes,
    ZendeskAuthenticationTypes,
    ZendeskIssueAuthenticationTypes,
)


class GetFeed(BaseModel):
    feed: Optional["GetFeedFeed"]


class GetFeedFeed(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetFeedFeedOwner"
    state: EntityState
    identifier: Optional[str]
    description: Optional[str]
    correlation_id: Optional[str] = Field(alias="correlationId")
    type: FeedTypes
    sync_mode: Optional[FeedSyncMode] = Field(alias="syncMode")
    site: Optional["GetFeedFeedSite"]
    email: Optional["GetFeedFeedEmail"]
    issue: Optional["GetFeedFeedIssue"]
    initiative: Optional["GetFeedFeedInitiative"]
    commit: Optional["GetFeedFeedCommit"]
    pull_request: Optional["GetFeedFeedPullRequest"] = Field(alias="pullRequest")
    crm: Optional["GetFeedFeedCrm"]
    hris: Optional["GetFeedFeedHris"]
    calendar: Optional["GetFeedFeedCalendar"]
    meeting: Optional["GetFeedFeedMeeting"]
    rss: Optional["GetFeedFeedRss"]
    web: Optional["GetFeedFeedWeb"]
    search: Optional["GetFeedFeedSearch"]
    reddit: Optional["GetFeedFeedReddit"]
    linked_in: Optional["GetFeedFeedLinkedIn"] = Field(alias="linkedIn")
    notion: Optional["GetFeedFeedNotion"]
    confluence: Optional["GetFeedFeedConfluence"]
    intercom: Optional["GetFeedFeedIntercom"]
    zendesk: Optional["GetFeedFeedZendesk"]
    youtube: Optional["GetFeedFeedYoutube"]
    twitter: Optional["GetFeedFeedTwitter"]
    slack: Optional["GetFeedFeedSlack"]
    microsoft_teams: Optional["GetFeedFeedMicrosoftTeams"] = Field(
        alias="microsoftTeams"
    )
    discord: Optional["GetFeedFeedDiscord"]
    attio: Optional["GetFeedFeedAttio"]
    salesforce: Optional["GetFeedFeedSalesforce"]
    hub_spot_conversations: Optional["GetFeedFeedHubSpotConversations"] = Field(
        alias="hubSpotConversations"
    )
    intercom_conversations: Optional["GetFeedFeedIntercomConversations"] = Field(
        alias="intercomConversations"
    )
    productlane: Optional["GetFeedFeedProductlane"]
    research: Optional["GetFeedFeedResearch"]
    entity: Optional["GetFeedFeedEntity"]
    error: Optional[str]
    last_post_date: Optional[Any] = Field(alias="lastPostDate")
    last_read_date: Optional[Any] = Field(alias="lastReadDate")
    read_count: Optional[int] = Field(alias="readCount")
    workflow: Optional["GetFeedFeedWorkflow"]
    schedule_policy: Optional["GetFeedFeedSchedulePolicy"] = Field(
        alias="schedulePolicy"
    )


class GetFeedFeedOwner(BaseModel):
    id: str


class GetFeedFeedSite(BaseModel):
    site_type: SiteTypes = Field(alias="siteType")
    type: FeedServiceTypes
    is_recursive: Optional[bool] = Field(alias="isRecursive")
    allowed_paths: Optional[list[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[list[str]] = Field(alias="excludedPaths")
    s_3: Optional["GetFeedFeedSiteS3"] = Field(alias="s3")
    azure_blob: Optional["GetFeedFeedSiteAzureBlob"] = Field(alias="azureBlob")
    azure_file: Optional["GetFeedFeedSiteAzureFile"] = Field(alias="azureFile")
    google: Optional["GetFeedFeedSiteGoogle"]
    share_point: Optional["GetFeedFeedSiteSharePoint"] = Field(alias="sharePoint")
    one_drive: Optional["GetFeedFeedSiteOneDrive"] = Field(alias="oneDrive")
    google_drive: Optional["GetFeedFeedSiteGoogleDrive"] = Field(alias="googleDrive")
    dropbox: Optional["GetFeedFeedSiteDropbox"]
    box: Optional["GetFeedFeedSiteBox"]
    github: Optional["GetFeedFeedSiteGithub"]
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedSiteS3(BaseModel):
    access_key: Optional[str] = Field(alias="accessKey")
    secret_access_key: Optional[str] = Field(alias="secretAccessKey")
    bucket_name: Optional[str] = Field(alias="bucketName")
    prefix: Optional[str]
    region: Optional[str]
    custom_endpoint: Optional[str] = Field(alias="customEndpoint")


class GetFeedFeedSiteAzureBlob(BaseModel):
    storage_access_key: Optional[str] = Field(alias="storageAccessKey")
    account_name: Optional[str] = Field(alias="accountName")
    container_name: Optional[str] = Field(alias="containerName")
    prefix: Optional[str]
    list_type: Optional[BlobListingTypes] = Field(alias="listType")


class GetFeedFeedSiteAzureFile(BaseModel):
    storage_access_key: Optional[str] = Field(alias="storageAccessKey")
    account_name: Optional[str] = Field(alias="accountName")
    share_name: Optional[str] = Field(alias="shareName")
    prefix: Optional[str]


class GetFeedFeedSiteGoogle(BaseModel):
    credentials: Optional[str]
    container_name: Optional[str] = Field(alias="containerName")
    prefix: Optional[str]


class GetFeedFeedSiteSharePoint(BaseModel):
    authentication_type: Optional[SharePointAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    account_name: str = Field(alias="accountName")
    library_id: str = Field(alias="libraryId")
    folder_id: Optional[str] = Field(alias="folderId")
    tenant_id: Optional[str] = Field(alias="tenantId")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedSiteSharePointConnector"]


class GetFeedFeedSiteSharePointConnector(BaseModel):
    id: str


class GetFeedFeedSiteOneDrive(BaseModel):
    authentication_type: Optional[OneDriveAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    folder_id: Optional[str] = Field(alias="folderId")
    files: Optional[list[Optional[str]]]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedSiteOneDriveConnector"]


class GetFeedFeedSiteOneDriveConnector(BaseModel):
    id: str


class GetFeedFeedSiteGoogleDrive(BaseModel):
    authentication_type: Optional[GoogleDriveAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    drive_id: Optional[str] = Field(alias="driveId")
    folder_id: Optional[str] = Field(alias="folderId")
    files: Optional[list[Optional[str]]]
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    service_account_json: Optional[str] = Field(alias="serviceAccountJson")
    connector: Optional["GetFeedFeedSiteGoogleDriveConnector"]


class GetFeedFeedSiteGoogleDriveConnector(BaseModel):
    id: str


class GetFeedFeedSiteDropbox(BaseModel):
    authentication_type: Optional[DropboxAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    path: Optional[str]
    app_key: Optional[str] = Field(alias="appKey")
    app_secret: Optional[str] = Field(alias="appSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedSiteDropboxConnector"]


class GetFeedFeedSiteDropboxConnector(BaseModel):
    id: str


class GetFeedFeedSiteBox(BaseModel):
    authentication_type: Optional[BoxAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    folder_id: Optional[str] = Field(alias="folderId")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    redirect_uri: Optional[str] = Field(alias="redirectUri")
    connector: Optional["GetFeedFeedSiteBoxConnector"]


class GetFeedFeedSiteBoxConnector(BaseModel):
    id: str


class GetFeedFeedSiteGithub(BaseModel):
    authentication_type: Optional[GitHubAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[Any]
    repository_owner: str = Field(alias="repositoryOwner")
    repository_name: str = Field(alias="repositoryName")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    connector: Optional["GetFeedFeedSiteGithubConnector"]


class GetFeedFeedSiteGithubConnector(BaseModel):
    id: str


class GetFeedFeedEmail(BaseModel):
    type: FeedServiceTypes
    include_attachments: Optional[bool] = Field(alias="includeAttachments")
    google: Optional["GetFeedFeedEmailGoogle"]
    microsoft: Optional["GetFeedFeedEmailMicrosoft"]
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedEmailGoogle(BaseModel):
    type: Optional[EmailListingTypes]
    filter: Optional[str]
    include_spam: Optional[bool] = Field(alias="includeSpam")
    exclude_sent_items: Optional[bool] = Field(alias="excludeSentItems")
    include_deleted_items: Optional[bool] = Field(alias="includeDeletedItems")
    inbox_only: Optional[bool] = Field(alias="inboxOnly")
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    authentication_type: Optional[GoogleEmailAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    connector: Optional["GetFeedFeedEmailGoogleConnector"]


class GetFeedFeedEmailGoogleConnector(BaseModel):
    id: str


class GetFeedFeedEmailMicrosoft(BaseModel):
    type: Optional[EmailListingTypes]
    filter: Optional[str]
    include_spam: Optional[bool] = Field(alias="includeSpam")
    exclude_sent_items: Optional[bool] = Field(alias="excludeSentItems")
    include_deleted_items: Optional[bool] = Field(alias="includeDeletedItems")
    inbox_only: Optional[bool] = Field(alias="inboxOnly")
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    authentication_type: Optional[MicrosoftEmailAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    connector: Optional["GetFeedFeedEmailMicrosoftConnector"]


class GetFeedFeedEmailMicrosoftConnector(BaseModel):
    id: str


class GetFeedFeedIssue(BaseModel):
    type: FeedServiceTypes
    include_attachments: Optional[bool] = Field(alias="includeAttachments")
    jira: Optional["GetFeedFeedIssueJira"]
    linear: Optional["GetFeedFeedIssueLinear"]
    github: Optional["GetFeedFeedIssueGithub"]
    intercom: Optional["GetFeedFeedIssueIntercom"]
    zendesk: Optional["GetFeedFeedIssueZendesk"]
    trello: Optional["GetFeedFeedIssueTrello"]
    attio: Optional["GetFeedFeedIssueAttio"]
    salesforce: Optional["GetFeedFeedIssueSalesforce"]
    hub_spot: Optional["GetFeedFeedIssueHubSpot"] = Field(alias="hubSpot")
    asana: Optional["GetFeedFeedIssueAsana"]
    monday: Optional["GetFeedFeedIssueMonday"]
    productlane: Optional["GetFeedFeedIssueProductlane"]
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedIssueJira(BaseModel):
    authentication_type: Optional[JiraAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[Any]
    project: Optional[str]
    email: Optional[str]
    token: Optional[str]
    offset: Optional[Any]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedIssueJiraConnector"]
    cloud_id: Optional[str] = Field(alias="cloudId")


class GetFeedFeedIssueJiraConnector(BaseModel):
    id: str


class GetFeedFeedIssueLinear(BaseModel):
    authentication_type: Optional[LinearAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    key: Optional[str]
    project: str
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedIssueLinearConnector"]


class GetFeedFeedIssueLinearConnector(BaseModel):
    id: str


class GetFeedFeedIssueGithub(BaseModel):
    authentication_type: Optional[GitHubAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[Any]
    repository_owner: str = Field(alias="repositoryOwner")
    repository_name: str = Field(alias="repositoryName")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    connector: Optional["GetFeedFeedIssueGithubConnector"]


class GetFeedFeedIssueGithubConnector(BaseModel):
    id: str


class GetFeedFeedIssueIntercom(BaseModel):
    authentication_type: Optional[IntercomIssueAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    access_token: Optional[str] = Field(alias="accessToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedIssueIntercomConnector"]


class GetFeedFeedIssueIntercomConnector(BaseModel):
    id: str


class GetFeedFeedIssueZendesk(BaseModel):
    authentication_type: Optional[ZendeskIssueAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    subdomain: str
    access_token: Optional[str] = Field(alias="accessToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedIssueZendeskConnector"]


class GetFeedFeedIssueZendeskConnector(BaseModel):
    id: str


class GetFeedFeedIssueTrello(BaseModel):
    key: str
    token: str
    identifiers: list[str]
    type: TrelloTypes


class GetFeedFeedIssueAttio(BaseModel):
    authentication_type: Optional[AttioIssueAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    api_key: Optional[str] = Field(alias="apiKey")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedIssueAttioConnector"]


class GetFeedFeedIssueAttioConnector(BaseModel):
    id: str


class GetFeedFeedIssueSalesforce(BaseModel):
    authentication_type: Optional[SalesforceIssueAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    is_sandbox: Optional[bool] = Field(alias="isSandbox")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedIssueSalesforceConnector"]


class GetFeedFeedIssueSalesforceConnector(BaseModel):
    id: str


class GetFeedFeedIssueHubSpot(BaseModel):
    authentication_type: Optional[HubSpotIssueAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    access_token: Optional[str] = Field(alias="accessToken")
    connector: Optional["GetFeedFeedIssueHubSpotConnector"]


class GetFeedFeedIssueHubSpotConnector(BaseModel):
    id: str


class GetFeedFeedIssueAsana(BaseModel):
    authentication_type: Optional[AsanaAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    workspace_id: Optional[str] = Field(alias="workspaceId")
    project_id: Optional[str] = Field(alias="projectId")


class GetFeedFeedIssueMonday(BaseModel):
    api_token: str = Field(alias="apiToken")
    board_id: str = Field(alias="boardId")


class GetFeedFeedIssueProductlane(BaseModel):
    api_key: Optional[str] = Field(alias="apiKey")
    workspace_id: Optional[str] = Field(alias="workspaceId")


class GetFeedFeedInitiative(BaseModel):
    type: FeedServiceTypes
    jira: Optional["GetFeedFeedInitiativeJira"]
    github: Optional["GetFeedFeedInitiativeGithub"]
    linear: Optional["GetFeedFeedInitiativeLinear"]
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedInitiativeJira(BaseModel):
    authentication_type: Optional[JiraAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[str]
    project: Optional[str]
    email: Optional[str]
    token: Optional[str]
    offset: Optional[Any]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedInitiativeJiraConnector"]
    cloud_id: Optional[str] = Field(alias="cloudId")


class GetFeedFeedInitiativeJiraConnector(BaseModel):
    id: str


class GetFeedFeedInitiativeGithub(BaseModel):
    authentication_type: Optional[GitHubAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[str]
    repository_owner: Optional[str] = Field(alias="repositoryOwner")
    repository_name: Optional[str] = Field(alias="repositoryName")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedInitiativeGithubConnector"]
    authorization_id: Optional[str] = Field(alias="authorizationId")


class GetFeedFeedInitiativeGithubConnector(BaseModel):
    id: str


class GetFeedFeedInitiativeLinear(BaseModel):
    authentication_type: Optional[LinearAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    key: Optional[str]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedInitiativeLinearConnector"]


class GetFeedFeedInitiativeLinearConnector(BaseModel):
    id: str


class GetFeedFeedCommit(BaseModel):
    type: FeedServiceTypes
    github: Optional["GetFeedFeedCommitGithub"]
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedCommitGithub(BaseModel):
    authentication_type: Optional[GitHubCommitAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[Any]
    repository_owner: str = Field(alias="repositoryOwner")
    repository_name: str = Field(alias="repositoryName")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    connector: Optional["GetFeedFeedCommitGithubConnector"]


class GetFeedFeedCommitGithubConnector(BaseModel):
    id: str


class GetFeedFeedPullRequest(BaseModel):
    type: FeedServiceTypes
    github: Optional["GetFeedFeedPullRequestGithub"]
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedPullRequestGithub(BaseModel):
    authentication_type: Optional[GitHubPullRequestAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[Any]
    repository_owner: str = Field(alias="repositoryOwner")
    repository_name: str = Field(alias="repositoryName")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    personal_access_token: Optional[str] = Field(alias="personalAccessToken")
    connector: Optional["GetFeedFeedPullRequestGithubConnector"]


class GetFeedFeedPullRequestGithubConnector(BaseModel):
    id: str


class GetFeedFeedCrm(BaseModel):
    type: FeedServiceTypes
    attio: Optional["GetFeedFeedCrmAttio"]
    google_contacts: Optional["GetFeedFeedCrmGoogleContacts"] = Field(
        alias="googleContacts"
    )
    microsoft_contacts: Optional["GetFeedFeedCrmMicrosoftContacts"] = Field(
        alias="microsoftContacts"
    )
    salesforce: Optional["GetFeedFeedCrmSalesforce"]
    hub_spot: Optional["GetFeedFeedCrmHubSpot"] = Field(alias="hubSpot")
    productlane: Optional["GetFeedFeedCrmProductlane"]
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedCrmAttio(BaseModel):
    authentication_type: Optional[AttioAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    api_key: Optional[str] = Field(alias="apiKey")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedCrmAttioConnector"]
    type: Optional[FeedListingTypes]


class GetFeedFeedCrmAttioConnector(BaseModel):
    id: str


class GetFeedFeedCrmGoogleContacts(BaseModel):
    authentication_type: Optional[GoogleContactsAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedCrmGoogleContactsConnector"]
    type: Optional[FeedListingTypes]


class GetFeedFeedCrmGoogleContactsConnector(BaseModel):
    id: str


class GetFeedFeedCrmMicrosoftContacts(BaseModel):
    authentication_type: Optional[MicrosoftContactsAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    tenant_id: Optional[str] = Field(alias="tenantId")
    connector: Optional["GetFeedFeedCrmMicrosoftContactsConnector"]
    type: Optional[FeedListingTypes]


class GetFeedFeedCrmMicrosoftContactsConnector(BaseModel):
    id: str


class GetFeedFeedCrmSalesforce(BaseModel):
    authentication_type: Optional[SalesforceAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    instance_url: Optional[str] = Field(alias="instanceUrl")
    is_sandbox: Optional[bool] = Field(alias="isSandbox")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedCrmSalesforceConnector"]
    type: Optional[FeedListingTypes]


class GetFeedFeedCrmSalesforceConnector(BaseModel):
    id: str


class GetFeedFeedCrmHubSpot(BaseModel):
    authentication_type: Optional[HubSpotAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    access_token: Optional[str] = Field(alias="accessToken")
    connector: Optional["GetFeedFeedCrmHubSpotConnector"]
    type: Optional[FeedListingTypes]


class GetFeedFeedCrmHubSpotConnector(BaseModel):
    id: str


class GetFeedFeedCrmProductlane(BaseModel):
    api_key: Optional[str] = Field(alias="apiKey")
    type: Optional[FeedListingTypes]


class GetFeedFeedHris(BaseModel):
    type: FeedServiceTypes
    bamboo_hr: Optional["GetFeedFeedHrisBambooHr"] = Field(alias="bambooHR")
    gusto: Optional["GetFeedFeedHrisGusto"]
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedHrisBambooHr(BaseModel):
    authentication_type: Optional[BambooHRAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    api_key: Optional[str] = Field(alias="apiKey")
    company_domain: Optional[str] = Field(alias="companyDomain")


class GetFeedFeedHrisGusto(BaseModel):
    authentication_type: Optional[GustoAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    company_id: Optional[str] = Field(alias="companyId")


class GetFeedFeedCalendar(BaseModel):
    type: FeedServiceTypes
    include_attachments: Optional[bool] = Field(alias="includeAttachments")
    enable_meeting_recording: Optional[bool] = Field(alias="enableMeetingRecording")
    meeting_bot_name: Optional[str] = Field(alias="meetingBotName")
    google: Optional["GetFeedFeedCalendarGoogle"]
    microsoft: Optional["GetFeedFeedCalendarMicrosoft"]
    read_limit: Optional[int] = Field(alias="readLimit")


class GetFeedFeedCalendarGoogle(BaseModel):
    type: Optional[CalendarListingTypes]
    calendar_id: Optional[str] = Field(alias="calendarId")
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    authentication_type: Optional[GoogleCalendarAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    connector: Optional["GetFeedFeedCalendarGoogleConnector"]


class GetFeedFeedCalendarGoogleConnector(BaseModel):
    id: str


class GetFeedFeedCalendarMicrosoft(BaseModel):
    type: Optional[CalendarListingTypes]
    calendar_id: Optional[str] = Field(alias="calendarId")
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    authentication_type: Optional[MicrosoftCalendarAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    refresh_token: Optional[str] = Field(alias="refreshToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    connector: Optional["GetFeedFeedCalendarMicrosoftConnector"]


class GetFeedFeedCalendarMicrosoftConnector(BaseModel):
    id: str


class GetFeedFeedMeeting(BaseModel):
    type: FeedServiceTypes
    content_type: Optional[MeetingContentTypes] = Field(alias="contentType")
    read_limit: Optional[int] = Field(alias="readLimit")
    fireflies: Optional["GetFeedFeedMeetingFireflies"]
    attio: Optional["GetFeedFeedMeetingAttio"]
    fathom: Optional["GetFeedFeedMeetingFathom"]
    hub_spot: Optional["GetFeedFeedMeetingHubSpot"] = Field(alias="hubSpot")
    krisp: Optional["GetFeedFeedMeetingKrisp"]


class GetFeedFeedMeetingFireflies(BaseModel):
    api_key: Optional[str] = Field(alias="apiKey")
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    type: Optional[FeedListingTypes]


class GetFeedFeedMeetingAttio(BaseModel):
    authentication_type: Optional[AttioMeetingAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    api_key: Optional[str] = Field(alias="apiKey")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedMeetingAttioConnector"]
    after_date: Optional[Any] = Field(alias="afterDate")
    before_date: Optional[Any] = Field(alias="beforeDate")
    type: Optional[FeedListingTypes]


class GetFeedFeedMeetingAttioConnector(BaseModel):
    id: str


class GetFeedFeedMeetingFathom(BaseModel):
    api_key: Optional[str] = Field(alias="apiKey")
    after_date: Optional[Any] = Field(alias="afterDate")
    before_date: Optional[Any] = Field(alias="beforeDate")
    type: Optional[FeedListingTypes]


class GetFeedFeedMeetingHubSpot(BaseModel):
    authentication_type: Optional[HubSpotFeedAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    access_token: Optional[str] = Field(alias="accessToken")
    include_transcripts: Optional[bool] = Field(alias="includeTranscripts")
    after_date: Optional[Any] = Field(alias="afterDate")
    before_date: Optional[Any] = Field(alias="beforeDate")
    read_limit: Optional[int] = Field(alias="readLimit")
    connector: Optional["GetFeedFeedMeetingHubSpotConnector"]
    type: Optional[FeedListingTypes]


class GetFeedFeedMeetingHubSpotConnector(BaseModel):
    id: str


class GetFeedFeedMeetingKrisp(BaseModel):
    auth_token: Optional[str] = Field(alias="authToken")
    type: Optional[FeedListingTypes]


class GetFeedFeedRss(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    uri: Any


class GetFeedFeedWeb(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    uri: Any
    include_files: Optional[bool] = Field(alias="includeFiles")
    allowed_paths: Optional[list[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[list[str]] = Field(alias="excludedPaths")


class GetFeedFeedSearch(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[SearchServiceTypes]
    text: Optional[str]
    exa: Optional["GetFeedFeedSearchExa"]
    crustdata: Optional["GetFeedFeedSearchCrustdata"]


class GetFeedFeedSearchExa(BaseModel):
    search_type: Optional[ExaSearchTypes] = Field(alias="searchType")


class GetFeedFeedSearchCrustdata(BaseModel):
    signal_type: Optional[CrustdataWatcherSignalTypes] = Field(alias="signalType")
    company_domain: Optional[str] = Field(alias="companyDomain")
    company_linked_in_url: Optional[str] = Field(alias="companyLinkedInUrl")
    company_id: Optional[str] = Field(alias="companyId")
    person_linked_in_urls: Optional[list[str]] = Field(alias="personLinkedInUrls")
    job_title: Optional[str] = Field(alias="jobTitle")
    job_region: Optional[str] = Field(alias="jobRegion")
    job_description: Optional[str] = Field(alias="jobDescription")


class GetFeedFeedReddit(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    subreddit_name: str = Field(alias="subredditName")


class GetFeedFeedLinkedIn(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    listing_type: Optional[LinkedInPostListingTypes] = Field(alias="listingType")
    company_domain: Optional[str] = Field(alias="companyDomain")
    company_linked_in_url: Optional[str] = Field(alias="companyLinkedInUrl")
    company_name: Optional[str] = Field(alias="companyName")
    person_linked_in_url: Optional[str] = Field(alias="personLinkedInUrl")
    post_types: Optional[str] = Field(alias="postTypes")
    keyword: Optional[str]
    date_posted: Optional[str] = Field(alias="datePosted")
    exact_keyword_match: Optional[bool] = Field(alias="exactKeywordMatch")
    content_types: Optional[list[Optional[LinkedInPostContentTypes]]] = Field(
        alias="contentTypes"
    )
    include_comments: Optional[bool] = Field(alias="includeComments")
    max_comments: Optional[int] = Field(alias="maxComments")


class GetFeedFeedNotion(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[NotionAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    token: Optional[str]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedNotionConnector"]
    identifiers: list[str]
    type: NotionTypes


class GetFeedFeedNotionConnector(BaseModel):
    id: str


class GetFeedFeedConfluence(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[ConfluenceAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    uri: Optional[str]
    email: Optional[str]
    token: Optional[str]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedConfluenceConnector"]
    cloud_id: Optional[str] = Field(alias="cloudId")
    space_keys: Optional[list[str]] = Field(alias="spaceKeys")
    identifiers: Optional[list[str]]
    type: ConfluenceTypes
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class GetFeedFeedConfluenceConnector(BaseModel):
    id: str


class GetFeedFeedIntercom(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[IntercomAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    access_token: Optional[str] = Field(alias="accessToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedIntercomConnector"]


class GetFeedFeedIntercomConnector(BaseModel):
    id: str


class GetFeedFeedZendesk(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[ZendeskAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    subdomain: str
    access_token: Optional[str] = Field(alias="accessToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedZendeskConnector"]


class GetFeedFeedZendeskConnector(BaseModel):
    id: str


class GetFeedFeedYoutube(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: YouTubeTypes
    video_name: Optional[str] = Field(alias="videoName")
    video_identifiers: Optional[list[str]] = Field(alias="videoIdentifiers")
    channel_identifier: Optional[str] = Field(alias="channelIdentifier")
    playlist_identifier: Optional[str] = Field(alias="playlistIdentifier")


class GetFeedFeedTwitter(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[TwitterAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    token: Optional[str]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedTwitterConnector"]
    type: Optional[TwitterListingTypes]
    user_name: Optional[str] = Field(alias="userName")
    query: Optional[str]
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class GetFeedFeedTwitterConnector(BaseModel):
    id: str


class GetFeedFeedSlack(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[FeedListingTypes]
    authentication_type: Optional[SlackAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    token: Optional[str]
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedSlackConnector"]
    channel: str
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class GetFeedFeedSlackConnector(BaseModel):
    id: str


class GetFeedFeedMicrosoftTeams(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[FeedListingTypes]
    authentication_type: Optional[MicrosoftTeamsAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedMicrosoftTeamsConnector"]
    before_date: Optional[Any] = Field(alias="beforeDate")
    after_date: Optional[Any] = Field(alias="afterDate")
    team_id: str = Field(alias="teamId")
    channel_id: str = Field(alias="channelId")
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class GetFeedFeedMicrosoftTeamsConnector(BaseModel):
    id: str


class GetFeedFeedDiscord(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[FeedListingTypes]
    token: str
    channel: str
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class GetFeedFeedAttio(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[AttioFeedAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    api_key: Optional[str] = Field(alias="apiKey")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedAttioConnector"]


class GetFeedFeedAttioConnector(BaseModel):
    id: str


class GetFeedFeedSalesforce(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[SalesforceFeedAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    is_sandbox: Optional[bool] = Field(alias="isSandbox")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedSalesforceConnector"]


class GetFeedFeedSalesforceConnector(BaseModel):
    id: str


class GetFeedFeedHubSpotConversations(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[HubSpotFeedAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    client_id: Optional[str] = Field(alias="clientId")
    access_token: Optional[str] = Field(alias="accessToken")
    inbox_id: Optional[str] = Field(alias="inboxId")
    include_closed_threads: Optional[bool] = Field(alias="includeClosedThreads")
    include_attachments: Optional[bool] = Field(alias="includeAttachments")
    connector: Optional["GetFeedFeedHubSpotConversationsConnector"]


class GetFeedFeedHubSpotConversationsConnector(BaseModel):
    id: str


class GetFeedFeedIntercomConversations(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    authentication_type: Optional[IntercomConversationsAuthenticationTypes] = Field(
        alias="authenticationType"
    )
    access_token: Optional[str] = Field(alias="accessToken")
    client_id: Optional[str] = Field(alias="clientId")
    client_secret: Optional[str] = Field(alias="clientSecret")
    refresh_token: Optional[str] = Field(alias="refreshToken")
    connector: Optional["GetFeedFeedIntercomConversationsConnector"]
    state: Optional[str]
    include_notes: Optional[bool] = Field(alias="includeNotes")
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class GetFeedFeedIntercomConversationsConnector(BaseModel):
    id: str


class GetFeedFeedProductlane(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: FeedServiceTypes
    api_key: Optional[str] = Field(alias="apiKey")
    workspace_id: Optional[str] = Field(alias="workspaceId")


class GetFeedFeedResearch(BaseModel):
    read_limit: Optional[int] = Field(alias="readLimit")
    type: Optional[FeedServiceTypes]
    query: str
    parallel: Optional["GetFeedFeedResearchParallel"]


class GetFeedFeedResearchParallel(BaseModel):
    processor: Optional[ParallelProcessors]


class GetFeedFeedEntity(BaseModel):
    type: FeedServiceTypes
    query: Optional[str]
    read_limit: Optional[int] = Field(alias="readLimit")
    parallel: Optional["GetFeedFeedEntityParallel"]
    crustdata: Optional["GetFeedFeedEntityCrustdata"]


class GetFeedFeedEntityParallel(BaseModel):
    generator: Optional[ParallelGenerators]
    processor: Optional[ParallelProcessors]


class GetFeedFeedEntityCrustdata(BaseModel):
    person_filters: Optional["GetFeedFeedEntityCrustdataPersonFilters"] = Field(
        alias="personFilters"
    )
    company_filters: Optional["GetFeedFeedEntityCrustdataCompanyFilters"] = Field(
        alias="companyFilters"
    )


class GetFeedFeedEntityCrustdataPersonFilters(BaseModel):
    titles: Optional[list[str]]
    seniority_levels: Optional[list[str]] = Field(alias="seniorityLevels")
    function_categories: Optional[list[str]] = Field(alias="functionCategories")
    company_names: Optional[list[str]] = Field(alias="companyNames")
    company_domains: Optional[list[str]] = Field(alias="companyDomains")
    company_linked_in_urls: Optional[list[str]] = Field(alias="companyLinkedInUrls")
    industries: Optional[list[str]]
    regions: Optional[list[str]]
    countries: Optional[list[str]]
    skills: Optional[list[str]]
    schools: Optional[list[str]]
    min_years_experience: Optional[int] = Field(alias="minYearsExperience")
    max_years_experience: Optional[int] = Field(alias="maxYearsExperience")
    min_connections: Optional[int] = Field(alias="minConnections")
    recently_changed_jobs: Optional[bool] = Field(alias="recentlyChangedJobs")


class GetFeedFeedEntityCrustdataCompanyFilters(BaseModel):
    names: Optional[list[str]]
    domains: Optional[list[str]]
    industries: Optional[list[str]]
    categories: Optional[list[str]]
    countries: Optional[list[str]]
    locations: Optional[list[str]]
    company_types: Optional[list[str]] = Field(alias="companyTypes")
    min_employee_count: Optional[int] = Field(alias="minEmployeeCount")
    max_employee_count: Optional[int] = Field(alias="maxEmployeeCount")
    min_growth_6_m_percent: Optional[Any] = Field(alias="minGrowth6mPercent")
    min_growth_12_m_percent: Optional[Any] = Field(alias="minGrowth12mPercent")
    funding_round_types: Optional[list[str]] = Field(alias="fundingRoundTypes")
    min_funding_date: Optional[Any] = Field(alias="minFundingDate")
    min_total_funding_usd: Optional[Any] = Field(alias="minTotalFundingUsd")
    min_revenue_lower_bound_usd: Optional[Any] = Field(alias="minRevenueLowerBoundUsd")
    max_revenue_upper_bound_usd: Optional[Any] = Field(alias="maxRevenueUpperBoundUsd")
    min_year_founded: Optional[int] = Field(alias="minYearFounded")
    max_year_founded: Optional[int] = Field(alias="maxYearFounded")


class GetFeedFeedWorkflow(BaseModel):
    id: str
    name: str


class GetFeedFeedSchedulePolicy(BaseModel):
    recurrence_type: Optional[TimedPolicyRecurrenceTypes] = Field(
        alias="recurrenceType"
    )
    repeat_interval: Optional[Any] = Field(alias="repeatInterval")


GetFeed.model_rebuild()
GetFeedFeed.model_rebuild()
GetFeedFeedSite.model_rebuild()
GetFeedFeedSiteSharePoint.model_rebuild()
GetFeedFeedSiteOneDrive.model_rebuild()
GetFeedFeedSiteGoogleDrive.model_rebuild()
GetFeedFeedSiteDropbox.model_rebuild()
GetFeedFeedSiteBox.model_rebuild()
GetFeedFeedSiteGithub.model_rebuild()
GetFeedFeedEmail.model_rebuild()
GetFeedFeedEmailGoogle.model_rebuild()
GetFeedFeedEmailMicrosoft.model_rebuild()
GetFeedFeedIssue.model_rebuild()
GetFeedFeedIssueJira.model_rebuild()
GetFeedFeedIssueLinear.model_rebuild()
GetFeedFeedIssueGithub.model_rebuild()
GetFeedFeedIssueIntercom.model_rebuild()
GetFeedFeedIssueZendesk.model_rebuild()
GetFeedFeedIssueAttio.model_rebuild()
GetFeedFeedIssueSalesforce.model_rebuild()
GetFeedFeedIssueHubSpot.model_rebuild()
GetFeedFeedInitiative.model_rebuild()
GetFeedFeedInitiativeJira.model_rebuild()
GetFeedFeedInitiativeGithub.model_rebuild()
GetFeedFeedInitiativeLinear.model_rebuild()
GetFeedFeedCommit.model_rebuild()
GetFeedFeedCommitGithub.model_rebuild()
GetFeedFeedPullRequest.model_rebuild()
GetFeedFeedPullRequestGithub.model_rebuild()
GetFeedFeedCrm.model_rebuild()
GetFeedFeedCrmAttio.model_rebuild()
GetFeedFeedCrmGoogleContacts.model_rebuild()
GetFeedFeedCrmMicrosoftContacts.model_rebuild()
GetFeedFeedCrmSalesforce.model_rebuild()
GetFeedFeedCrmHubSpot.model_rebuild()
GetFeedFeedHris.model_rebuild()
GetFeedFeedCalendar.model_rebuild()
GetFeedFeedCalendarGoogle.model_rebuild()
GetFeedFeedCalendarMicrosoft.model_rebuild()
GetFeedFeedMeeting.model_rebuild()
GetFeedFeedMeetingAttio.model_rebuild()
GetFeedFeedMeetingHubSpot.model_rebuild()
GetFeedFeedSearch.model_rebuild()
GetFeedFeedNotion.model_rebuild()
GetFeedFeedConfluence.model_rebuild()
GetFeedFeedIntercom.model_rebuild()
GetFeedFeedZendesk.model_rebuild()
GetFeedFeedTwitter.model_rebuild()
GetFeedFeedSlack.model_rebuild()
GetFeedFeedMicrosoftTeams.model_rebuild()
GetFeedFeedAttio.model_rebuild()
GetFeedFeedSalesforce.model_rebuild()
GetFeedFeedHubSpotConversations.model_rebuild()
GetFeedFeedIntercomConversations.model_rebuild()
GetFeedFeedResearch.model_rebuild()
GetFeedFeedEntity.model_rebuild()
GetFeedFeedEntityCrustdata.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountInvestments(BaseModel):
    count_investments: Optional["CountInvestmentsCountInvestments"] = Field(
        alias="countInvestments"
    )


class CountInvestmentsCountInvestments(BaseModel):
    count: Optional[Any]


CountInvestments.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllAgents(BaseModel):
    delete_all_agents: Optional[list[Optional["DeleteAllAgentsDeleteAllAgents"]]] = (
        Field(alias="deleteAllAgents")
    )


class DeleteAllAgentsDeleteAllAgents(BaseModel):
    id: str
    state: EntityState


DeleteAllAgents.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class EnrichPlaces(BaseModel):
    enrich_places: Optional[list[Optional["EnrichPlacesEnrichPlaces"]]] = Field(
        alias="enrichPlaces"
    )


class EnrichPlacesEnrichPlaces(BaseModel):
    id: str
    name: str


EnrichPlaces.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateEmotion(BaseModel):
    create_emotion: Optional["CreateEmotionCreateEmotion"] = Field(
        alias="createEmotion"
    )


class CreateEmotionCreateEmotion(BaseModel):
    id: str
    name: str


CreateEmotion.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class SuggestConversation(BaseModel):
    suggest_conversation: Optional["SuggestConversationSuggestConversation"] = Field(
        alias="suggestConversation"
    )


class SuggestConversationSuggestConversation(BaseModel):
    prompts: Optional[list[Optional[str]]]


SuggestConversation.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DistributionServiceTypes


class UpdateJiraIssue(BaseModel):
    update_jira_issue: Optional["UpdateJiraIssueUpdateJiraIssue"] = Field(
        alias="updateJiraIssue"
    )


class UpdateJiraIssueUpdateJiraIssue(BaseModel):
    identifier: Optional[str]
    uri: Optional[str]
    service_type: Optional[DistributionServiceTypes] = Field(alias="serviceType")


UpdateJiraIssue.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class EnableSkill(BaseModel):
    enable_skill: Optional["EnableSkillEnableSkill"] = Field(alias="enableSkill")


class EnableSkillEnableSkill(BaseModel):
    id: str
    state: EntityState


EnableSkill.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryMondayBoards(BaseModel):
    monday_boards: Optional["QueryMondayBoardsMondayBoards"] = Field(
        alias="mondayBoards"
    )


class QueryMondayBoardsMondayBoards(BaseModel):
    results: Optional[list[str]]


QueryMondayBoards.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllEvents(BaseModel):
    delete_all_events: Optional[list[Optional["DeleteAllEventsDeleteAllEvents"]]] = (
        Field(alias="deleteAllEvents")
    )


class DeleteAllEventsDeleteAllEvents(BaseModel):
    id: str
    state: EntityState


DeleteAllEvents.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalConditions(BaseModel):
    delete_medical_conditions: Optional[
        list[Optional["DeleteMedicalConditionsDeleteMedicalConditions"]]
    ] = Field(alias="deleteMedicalConditions")


class DeleteMedicalConditionsDeleteMedicalConditions(BaseModel):
    id: str
    state: EntityState


DeleteMedicalConditions.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CollectionTypes, EntityState


class RemoveContentsFromCollection(BaseModel):
    remove_contents_from_collection: Optional[
        "RemoveContentsFromCollectionRemoveContentsFromCollection"
    ] = Field(alias="removeContentsFromCollection")


class RemoveContentsFromCollectionRemoveContentsFromCollection(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[CollectionTypes]
    contents: Optional[
        list[
            Optional["RemoveContentsFromCollectionRemoveContentsFromCollectionContents"]
        ]
    ]


class RemoveContentsFromCollectionRemoveContentsFromCollectionContents(BaseModel):
    id: str
    name: str


RemoveContentsFromCollection.model_rebuild()
RemoveContentsFromCollectionRemoveContentsFromCollection.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteSkill(BaseModel):
    delete_skill: Optional["DeleteSkillDeleteSkill"] = Field(alias="deleteSkill")


class DeleteSkillDeleteSkill(BaseModel):
    id: str
    state: EntityState


DeleteSkill.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryConfluenceSpaces(BaseModel):
    confluence_spaces: Optional["QueryConfluenceSpacesConfluenceSpaces"] = Field(
        alias="confluenceSpaces"
    )


class QueryConfluenceSpacesConfluenceSpaces(BaseModel):
    results: Optional[list[Optional["QueryConfluenceSpacesConfluenceSpacesResults"]]]


class QueryConfluenceSpacesConfluenceSpacesResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]
    key: Optional[str]


QueryConfluenceSpaces.model_rebuild()
QueryConfluenceSpacesConfluenceSpaces.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllRepos(BaseModel):
    delete_all_repos: Optional[list[Optional["DeleteAllReposDeleteAllRepos"]]] = Field(
        alias="deleteAllRepos"
    )


class DeleteAllReposDeleteAllRepos(BaseModel):
    id: str
    state: EntityState


DeleteAllRepos.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityTypes, RelationshipDirections


class LookupEntity(BaseModel):
    lookup_entity: Optional["LookupEntityLookupEntity"] = Field(alias="lookupEntity")


class LookupEntityLookupEntity(BaseModel):
    entity: Optional["LookupEntityLookupEntityEntity"]
    relationships: Optional[list["LookupEntityLookupEntityRelationships"]]
    total_count: int = Field(alias="totalCount")


class LookupEntityLookupEntityEntity(BaseModel):
    id: str
    name: str
    type: EntityTypes
    metadata: Optional[str]


class LookupEntityLookupEntityRelationships(BaseModel):
    relation: str
    direction: RelationshipDirections
    entity: "LookupEntityLookupEntityRelationshipsEntity"


class LookupEntityLookupEntityRelationshipsEntity(BaseModel):
    id: str
    name: str
    type: EntityTypes
    metadata: Optional[str]


LookupEntity.model_rebuild()
LookupEntityLookupEntity.model_rebuild()
LookupEntityLookupEntityRelationships.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMicrosoftCalendarEvent(BaseModel):
    update_microsoft_calendar_event: Optional[
        "UpdateMicrosoftCalendarEventUpdateMicrosoftCalendarEvent"
    ] = Field(alias="updateMicrosoftCalendarEvent")


class UpdateMicrosoftCalendarEventUpdateMicrosoftCalendarEvent(BaseModel):
    event_id: str = Field(alias="eventId")
    summary: Optional[str]
    start_date_time: Any = Field(alias="startDateTime")
    end_date_time: Any = Field(alias="endDateTime")
    location: Optional[str]
    attendees: Optional[list[Optional[str]]]
    is_online_meeting: Optional[bool] = Field(alias="isOnlineMeeting")
    meeting_link: Optional[str] = Field(alias="meetingLink")
    description: Optional[str]
    status: Optional[str]
    organizer: Optional[str]


UpdateMicrosoftCalendarEvent.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DistributionServiceTypes


class UpdateLinearIssue(BaseModel):
    update_linear_issue: Optional["UpdateLinearIssueUpdateLinearIssue"] = Field(
        alias="updateLinearIssue"
    )


class UpdateLinearIssueUpdateLinearIssue(BaseModel):
    identifier: Optional[str]
    uri: Optional[str]
    service_type: Optional[DistributionServiceTypes] = Field(alias="serviceType")


UpdateLinearIssue.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DistributionServiceTypes


class UpdateConfluencePage(BaseModel):
    update_confluence_page: Optional["UpdateConfluencePageUpdateConfluencePage"] = (
        Field(alias="updateConfluencePage")
    )


class UpdateConfluencePageUpdateConfluencePage(BaseModel):
    identifier: Optional[str]
    uri: Optional[str]
    service_type: Optional[DistributionServiceTypes] = Field(alias="serviceType")


UpdateConfluencePage.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalContraindications(BaseModel):
    count_medical_contraindications: Optional[
        "CountMedicalContraindicationsCountMedicalContraindications"
    ] = Field(alias="countMedicalContraindications")


class CountMedicalContraindicationsCountMedicalContraindications(BaseModel):
    count: Optional[Any]


CountMedicalContraindications.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllFacts(BaseModel):
    delete_all_facts: Optional[list[Optional["DeleteAllFactsDeleteAllFacts"]]] = Field(
        alias="deleteAllFacts"
    )


class DeleteAllFactsDeleteAllFacts(BaseModel):
    id: str
    state: EntityState


DeleteAllFacts.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class GetPersona(BaseModel):
    persona: Optional["GetPersonaPersona"]


class GetPersonaPersona(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetPersonaPersonaOwner"
    state: EntityState
    identifier: Optional[str]
    platform: Optional[str]
    display_name: Optional[str] = Field(alias="displayName")
    timezone: Optional[str]
    role: Optional[str]
    instructions: Optional[str]
    facts: Optional[list["GetPersonaPersonaFacts"]]


class GetPersonaPersonaOwner(BaseModel):
    id: str


class GetPersonaPersonaFacts(BaseModel):
    id: Optional[str]
    text: Optional[str]


GetPersona.model_rebuild()
GetPersonaPersona.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class QueryMedicalDrugsClusters(BaseModel):
    medical_drugs: Optional["QueryMedicalDrugsClustersMedicalDrugs"] = Field(
        alias="medicalDrugs"
    )


class QueryMedicalDrugsClustersMedicalDrugs(BaseModel):
    results: Optional[list[Optional["QueryMedicalDrugsClustersMedicalDrugsResults"]]]
    clusters: Optional["QueryMedicalDrugsClustersMedicalDrugsClusters"]


class QueryMedicalDrugsClustersMedicalDrugsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryMedicalDrugsClustersMedicalDrugsResultsOwner"
    state: EntityState
    alternate_names: Optional[list[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[list[Optional["QueryMedicalDrugsClustersMedicalDrugsResultsFeeds"]]]
    links: Optional[list[Optional["QueryMedicalDrugsClustersMedicalDrugsResultsLinks"]]]
    workflow: Optional["QueryMedicalDrugsClustersMedicalDrugsResultsWorkflow"]
    location: Optional["QueryMedicalDrugsClustersMedicalDrugsResultsLocation"]
    h_3: Optional["QueryMedicalDrugsClustersMedicalDrugsResultsH3"] = Field(alias="h3")


class QueryMedicalDrugsClustersMedicalDrugsResultsOwner(BaseModel):
    id: str


class QueryMedicalDrugsClustersMedicalDrugsResultsFeeds(BaseModel):
    id: str
    name: str


class QueryMedicalDrugsClustersMedicalDrugsResultsLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class QueryMedicalDrugsClustersMedicalDrugsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryMedicalDrugsClustersMedicalDrugsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryMedicalDrugsClustersMedicalDrugsResultsH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class QueryMedicalDrugsClustersMedicalDrugsClusters(BaseModel):
    clusters: Optional[list["QueryMedicalDrugsClustersMedicalDrugsClustersClusters"]]


class QueryMedicalDrugsClustersMedicalDrugsClustersClusters(BaseModel):
    entities: list["QueryMedicalDrugsClustersMedicalDrugsClustersClustersEntities"]
    similarity: Optional[float]


class QueryMedicalDrugsClustersMedicalDrugsClustersClustersEntities(BaseModel):
    id: str
    name: Optional[str]


QueryMedicalDrugsClusters.model_rebuild()
QueryMedicalDrugsClustersMedicalDrugs.model_rebuild()
QueryMedicalDrugsClustersMedicalDrugsResults.model_rebuild()
QueryMedicalDrugsClustersMedicalDrugsClusters.model_rebuild()
QueryMedicalDrugsClustersMedicalDrugsClustersClusters.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteFact(BaseModel):
    delete_fact: Optional["DeleteFactDeleteFact"] = Field(alias="deleteFact")


class DeleteFactDeleteFact(BaseModel):
    id: str
    state: EntityState


DeleteFact.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalIndication(BaseModel):
    delete_medical_indication: Optional[
        "DeleteMedicalIndicationDeleteMedicalIndication"
    ] = Field(alias="deleteMedicalIndication")


class DeleteMedicalIndicationDeleteMedicalIndication(BaseModel):
    id: str
    state: EntityState


DeleteMedicalIndication.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class ExtractObservables(BaseModel):
    extract_observables: Optional["ExtractObservablesExtractObservables"] = Field(
        alias="extractObservables"
    )


class ExtractObservablesExtractObservables(BaseModel):
    labels: Optional[list[Optional["ExtractObservablesExtractObservablesLabels"]]]
    categories: Optional[
        list[Optional["ExtractObservablesExtractObservablesCategories"]]
    ]
    emotions: Optional[list[Optional["ExtractObservablesExtractObservablesEmotions"]]]
    persons: Optional[list[Optional["ExtractObservablesExtractObservablesPersons"]]]
    organizations: Optional[
        list[Optional["ExtractObservablesExtractObservablesOrganizations"]]
    ]
    places: Optional[list[Optional["ExtractObservablesExtractObservablesPlaces"]]]
    events: Optional[list[Optional["ExtractObservablesExtractObservablesEvents"]]]
    products: Optional[list[Optional["ExtractObservablesExtractObservablesProducts"]]]
    softwares: Optional[list[Optional["ExtractObservablesExtractObservablesSoftwares"]]]
    repos: Optional[list[Optional["ExtractObservablesExtractObservablesRepos"]]]
    investments: Optional[
        list[Optional["ExtractObservablesExtractObservablesInvestments"]]
    ]
    investment_funds: Optional[
        list[Optional["ExtractObservablesExtractObservablesInvestmentFunds"]]
    ] = Field(alias="investmentFunds")
    medical_studies: Optional[
        list[Optional["ExtractObservablesExtractObservablesMedicalStudies"]]
    ] = Field(alias="medicalStudies")
    medical_conditions: Optional[
        list[Optional["ExtractObservablesExtractObservablesMedicalConditions"]]
    ] = Field(alias="medicalConditions")
    medical_guidelines: Optional[
        list[Optional["ExtractObservablesExtractObservablesMedicalGuidelines"]]
    ] = Field(alias="medicalGuidelines")
    medical_drugs: Optional[
        list[Optional["ExtractObservablesExtractObservablesMedicalDrugs"]]
    ] = Field(alias="medicalDrugs")
    medical_drug_classes: Optional[
        list[Optional["ExtractObservablesExtractObservablesMedicalDrugClasses"]]
    ] = Field(alias="medicalDrugClasses")
    medical_indications: Optional[
        list[Optional["ExtractObservablesExtractObservablesMedicalIndications"]]
    ] = Field(alias="medicalIndications")
    medical_contraindications: Optional[
        list[Optional["ExtractObservablesExtractObservablesMedicalContraindications"]]
    ] = Field(alias="medicalContraindications")
    medical_procedures: Optional[
        list[Optional["ExtractObservablesExtractObservablesMedicalProcedures"]]
    ] = Field(alias="medicalProcedures")
    medical_therapies: Optional[
        list[Optional["ExtractObservablesExtractObservablesMedicalTherapies"]]
    ] = Field(alias="medicalTherapies")
    medical_devices: Optional[
        list[Optional["ExtractObservablesExtractObservablesMedicalDevices"]]
    ] = Field(alias="medicalDevices")
    medical_tests: Optional[
        list[Optional["ExtractObservablesExtractObservablesMedicalTests"]]
    ] = Field(alias="medicalTests")


class ExtractObservablesExtractObservablesLabels(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesCategories(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesEmotions(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesPersons(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesOrganizations(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesPlaces(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesEvents(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesProducts(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesSoftwares(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesRepos(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesInvestments(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesInvestmentFunds(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesMedicalStudies(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesMedicalConditions(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesMedicalGuidelines(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesMedicalDrugs(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesMedicalDrugClasses(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesMedicalIndications(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesMedicalContraindications(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesMedicalProcedures(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesMedicalTherapies(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesMedicalDevices(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


class ExtractObservablesExtractObservablesMedicalTests(BaseModel):
    name: Optional[str]
    metadata: Optional[str]


ExtractObservables.model_rebuild()
ExtractObservablesExtractObservables.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeletePlaces(BaseModel):
    delete_places: Optional[list[Optional["DeletePlacesDeletePlaces"]]] = Field(
        alias="deletePlaces"
    )


class DeletePlacesDeletePlaces(BaseModel):
    id: str
    state: EntityState


DeletePlaces.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeletePersona(BaseModel):
    delete_persona: Optional["DeletePersonaDeletePersona"] = Field(
        alias="deletePersona"
    )


class DeletePersonaDeletePersona(BaseModel):
    id: str
    state: EntityState


DeletePersona.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class LookupCompanies(BaseModel):
    lookup_companies: Optional["LookupCompaniesLookupCompanies"] = Field(
        alias="lookupCompanies"
    )


class LookupCompaniesLookupCompanies(BaseModel):
    results: Optional[list[Optional["LookupCompaniesLookupCompaniesResults"]]]


class LookupCompaniesLookupCompaniesResults(BaseModel):
    company_id: Optional[str] = Field(alias="companyId")
    company_name: Optional[str] = Field(alias="companyName")
    company_domain: Optional[str] = Field(alias="companyDomain")
    company_linked_in_url: Optional[Any] = Field(alias="companyLinkedInUrl")
    headquarters: Optional[str]
    hq_country: Optional[str] = Field(alias="hqCountry")
    headcount: Optional[int]
    employee_count_range: Optional[str] = Field(alias="employeeCountRange")
    industries: Optional[list[Optional[str]]]
    estimated_revenue_lower_bound: Optional[Any] = Field(
        alias="estimatedRevenueLowerBound"
    )
    estimated_revenue_upper_bound: Optional[Any] = Field(
        alias="estimatedRevenueUpperBound"
    )
    logo_url: Optional[Any] = Field(alias="logoUrl")


LookupCompanies.model_rebuild()
LookupCompaniesLookupCompanies.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ContentTypes,
    ConversationTypes,
    EntityState,
    FileTypes,
    FilterMode,
    ObservableTypes,
)


class QueryConversations(BaseModel):
    conversations: Optional["QueryConversationsConversations"]


class QueryConversationsConversations(BaseModel):
    results: Optional[list["QueryConversationsConversationsResults"]]


class QueryConversationsConversationsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryConversationsConversationsResultsOwner"
    state: EntityState
    correlation_id: Optional[str] = Field(alias="correlationId")
    type: Optional[ConversationTypes]
    transcript_uri: Optional[Any] = Field(alias="transcriptUri")
    message_count: Optional[int] = Field(alias="messageCount")
    turn_count: Optional[int] = Field(alias="turnCount")
    agent: Optional["QueryConversationsConversationsResultsAgent"]
    persona: Optional["QueryConversationsConversationsResultsPersona"]
    specification: Optional["QueryConversationsConversationsResultsSpecification"]
    fallbacks: Optional[
        list[Optional["QueryConversationsConversationsResultsFallbacks"]]
    ]
    filter: Optional["QueryConversationsConversationsResultsFilter"]
    augmented_filter: Optional[
        "QueryConversationsConversationsResultsAugmentedFilter"
    ] = Field(alias="augmentedFilter")
    summary: Optional[str]


class QueryConversationsConversationsResultsOwner(BaseModel):
    id: str


class QueryConversationsConversationsResultsAgent(BaseModel):
    id: str


class QueryConversationsConversationsResultsPersona(BaseModel):
    id: str
    name: str


class QueryConversationsConversationsResultsSpecification(BaseModel):
    id: str
    name: str


class QueryConversationsConversationsResultsFallbacks(BaseModel):
    id: str
    name: str


class QueryConversationsConversationsResultsFilter(BaseModel):
    date_range: Optional["QueryConversationsConversationsResultsFilterDateRange"] = (
        Field(alias="dateRange")
    )
    in_last: Optional[Any] = Field(alias="inLast")
    in_next: Optional[Any] = Field(alias="inNext")
    creation_date_range: Optional[
        "QueryConversationsConversationsResultsFilterCreationDateRange"
    ] = Field(alias="creationDateRange")
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[list[ContentTypes]]
    file_types: Optional[list[FileTypes]] = Field(alias="fileTypes")
    formats: Optional[list[str]]
    file_extensions: Optional[list[str]] = Field(alias="fileExtensions")
    file_size_range: Optional[
        "QueryConversationsConversationsResultsFilterFileSizeRange"
    ] = Field(alias="fileSizeRange")
    similar_contents: Optional[
        list["QueryConversationsConversationsResultsFilterSimilarContents"]
    ] = Field(alias="similarContents")
    contents: Optional[list["QueryConversationsConversationsResultsFilterContents"]]
    feeds: Optional[list["QueryConversationsConversationsResultsFilterFeeds"]]
    workflows: Optional[list["QueryConversationsConversationsResultsFilterWorkflows"]]
    collections: Optional[
        list["QueryConversationsConversationsResultsFilterCollections"]
    ]
    users: Optional[list["QueryConversationsConversationsResultsFilterUsers"]]
    observations: Optional[
        list["QueryConversationsConversationsResultsFilterObservations"]
    ]
    or_: Optional[list["QueryConversationsConversationsResultsFilterOr"]] = Field(
        alias="or"
    )
    and_: Optional[list["QueryConversationsConversationsResultsFilterAnd"]] = Field(
        alias="and"
    )
    has_observations: Optional[bool] = Field(alias="hasObservations")
    has_feeds: Optional[bool] = Field(alias="hasFeeds")
    has_collections: Optional[bool] = Field(alias="hasCollections")
    has_workflows: Optional[bool] = Field(alias="hasWorkflows")
    collection_mode: Optional[FilterMode] = Field(alias="collectionMode")
    observation_mode: Optional[FilterMode] = Field(alias="observationMode")


class QueryConversationsConversationsResultsFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsConversationsResultsFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsConversationsResultsFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsConversationsResultsFilterSimilarContents(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterContents(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterFeeds(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterWorkflows(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterCollections(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterUsers(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryConversationsConversationsResultsFilterObservationsObservable"
    states: Optional[list[EntityState]]


class QueryConversationsConversationsResultsFilterObservationsObservable(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterOr(BaseModel):
    feeds: Optional[list["QueryConversationsConversationsResultsFilterOrFeeds"]]
    workflows: Optional[list["QueryConversationsConversationsResultsFilterOrWorkflows"]]
    collections: Optional[
        list["QueryConversationsConversationsResultsFilterOrCollections"]
    ]
    users: Optional[list["QueryConversationsConversationsResultsFilterOrUsers"]]
    observations: Optional[
        list["QueryConversationsConversationsResultsFilterOrObservations"]
    ]


class QueryConversationsConversationsResultsFilterOrFeeds(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterOrWorkflows(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterOrCollections(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterOrUsers(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryConversationsConversationsResultsFilterOrObservationsObservable"
    states: Optional[list[EntityState]]


class QueryConversationsConversationsResultsFilterOrObservationsObservable(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterAnd(BaseModel):
    feeds: Optional[list["QueryConversationsConversationsResultsFilterAndFeeds"]]
    workflows: Optional[
        list["QueryConversationsConversationsResultsFilterAndWorkflows"]
    ]
    collections: Optional[
        list["QueryConversationsConversationsResultsFilterAndCollections"]
    ]
    users: Optional[list["QueryConversationsConversationsResultsFilterAndUsers"]]
    observations: Optional[
        list["QueryConversationsConversationsResultsFilterAndObservations"]
    ]


class QueryConversationsConversationsResultsFilterAndFeeds(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterAndWorkflows(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterAndCollections(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterAndUsers(BaseModel):
    id: str


class QueryConversationsConversationsResultsFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: "QueryConversationsConversationsResultsFilterAndObservationsObservable"
    states: Optional[list[EntityState]]


class QueryConversationsConversationsResultsFilterAndObservationsObservable(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilter(BaseModel):
    date_range: Optional[
        "QueryConversationsConversationsResultsAugmentedFilterDateRange"
    ] = Field(alias="dateRange")
    in_last: Optional[Any] = Field(alias="inLast")
    in_next: Optional[Any] = Field(alias="inNext")
    creation_date_range: Optional[
        "QueryConversationsConversationsResultsAugmentedFilterCreationDateRange"
    ] = Field(alias="creationDateRange")
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[list[ContentTypes]]
    file_types: Optional[list[FileTypes]] = Field(alias="fileTypes")
    formats: Optional[list[str]]
    file_extensions: Optional[list[str]] = Field(alias="fileExtensions")
    file_size_range: Optional[
        "QueryConversationsConversationsResultsAugmentedFilterFileSizeRange"
    ] = Field(alias="fileSizeRange")
    similar_contents: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterSimilarContents"]
    ] = Field(alias="similarContents")
    contents: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterContents"]
    ]
    feeds: Optional[list["QueryConversationsConversationsResultsAugmentedFilterFeeds"]]
    workflows: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterWorkflows"]
    ]
    collections: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterCollections"]
    ]
    users: Optional[list["QueryConversationsConversationsResultsAugmentedFilterUsers"]]
    observations: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterObservations"]
    ]
    or_: Optional[list["QueryConversationsConversationsResultsAugmentedFilterOr"]] = (
        Field(alias="or")
    )
    and_: Optional[list["QueryConversationsConversationsResultsAugmentedFilterAnd"]] = (
        Field(alias="and")
    )
    has_observations: Optional[bool] = Field(alias="hasObservations")
    has_feeds: Optional[bool] = Field(alias="hasFeeds")
    has_collections: Optional[bool] = Field(alias="hasCollections")
    has_workflows: Optional[bool] = Field(alias="hasWorkflows")
    collection_mode: Optional[FilterMode] = Field(alias="collectionMode")
    observation_mode: Optional[FilterMode] = Field(alias="observationMode")


class QueryConversationsConversationsResultsAugmentedFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsConversationsResultsAugmentedFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsConversationsResultsAugmentedFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsConversationsResultsAugmentedFilterSimilarContents(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterContents(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterFeeds(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterWorkflows(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterCollections(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterUsers(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterObservations(BaseModel):
    type: ObservableTypes
    observable: (
        "QueryConversationsConversationsResultsAugmentedFilterObservationsObservable"
    )
    states: Optional[list[EntityState]]


class QueryConversationsConversationsResultsAugmentedFilterObservationsObservable(
    BaseModel
):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterOr(BaseModel):
    feeds: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterOrFeeds"]
    ]
    workflows: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterOrWorkflows"]
    ]
    collections: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterOrCollections"]
    ]
    users: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterOrUsers"]
    ]
    observations: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterOrObservations"]
    ]


class QueryConversationsConversationsResultsAugmentedFilterOrFeeds(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterOrWorkflows(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterOrCollections(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterOrUsers(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: (
        "QueryConversationsConversationsResultsAugmentedFilterOrObservationsObservable"
    )
    states: Optional[list[EntityState]]


class QueryConversationsConversationsResultsAugmentedFilterOrObservationsObservable(
    BaseModel
):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterAnd(BaseModel):
    feeds: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterAndFeeds"]
    ]
    workflows: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterAndWorkflows"]
    ]
    collections: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterAndCollections"]
    ]
    users: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterAndUsers"]
    ]
    observations: Optional[
        list["QueryConversationsConversationsResultsAugmentedFilterAndObservations"]
    ]


class QueryConversationsConversationsResultsAugmentedFilterAndFeeds(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterAndWorkflows(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterAndCollections(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterAndUsers(BaseModel):
    id: str


class QueryConversationsConversationsResultsAugmentedFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: (
        "QueryConversationsConversationsResultsAugmentedFilterAndObservationsObservable"
    )
    states: Optional[list[EntityState]]


class QueryConversationsConversationsResultsAugmentedFilterAndObservationsObservable(
    BaseModel
):
    id: str


QueryConversations.model_rebuild()
QueryConversationsConversations.model_rebuild()
QueryConversationsConversationsResults.model_rebuild()
QueryConversationsConversationsResultsFilter.model_rebuild()
QueryConversationsConversationsResultsFilterObservations.model_rebuild()
QueryConversationsConversationsResultsFilterOr.model_rebuild()
QueryConversationsConversationsResultsFilterOrObservations.model_rebuild()
QueryConversationsConversationsResultsFilterAnd.model_rebuild()
QueryConversationsConversationsResultsFilterAndObservations.model_rebuild()
QueryConversationsConversationsResultsAugmentedFilter.model_rebuild()
QueryConversationsConversationsResultsAugmentedFilterObservations.model_rebuild()
QueryConversationsConversationsResultsAugmentedFilterOr.model_rebuild()
QueryConversationsConversationsResultsAugmentedFilterOrObservations.model_rebuild()
QueryConversationsConversationsResultsAugmentedFilterAnd.model_rebuild()
QueryConversationsConversationsResultsAugmentedFilterAndObservations.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class AddContentLabel(BaseModel):
    add_content_label: Optional["AddContentLabelAddContentLabel"] = Field(
        alias="addContentLabel"
    )


class AddContentLabelAddContentLabel(BaseModel):
    id: str
    name: str


AddContentLabel.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class DeleteGoogleCalendarEvent(BaseModel):
    delete_google_calendar_event: Optional[bool] = Field(
        alias="deleteGoogleCalendarEvent"
    )



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ObservableTypes


class RetrieveEntities(BaseModel):
    retrieve_entities: Optional["RetrieveEntitiesRetrieveEntities"] = Field(
        alias="retrieveEntities"
    )


class RetrieveEntitiesRetrieveEntities(BaseModel):
    results: Optional[list[Optional["RetrieveEntitiesRetrieveEntitiesResults"]]]


class RetrieveEntitiesRetrieveEntitiesResults(BaseModel):
    id: str
    name: Optional[str]
    type: ObservableTypes
    relevance: Optional[float]
    metadata: Optional[str]


RetrieveEntities.model_rebuild()
RetrieveEntitiesRetrieveEntities.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryNotionPages(BaseModel):
    notion_pages: Optional["QueryNotionPagesNotionPages"] = Field(alias="notionPages")


class QueryNotionPagesNotionPages(BaseModel):
    results: Optional[list[Optional["QueryNotionPagesNotionPagesResults"]]]


class QueryNotionPagesNotionPagesResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]


QueryNotionPages.model_rebuild()
QueryNotionPagesNotionPages.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class ViewExists(BaseModel):
    view_exists: Optional["ViewExistsViewExists"] = Field(alias="viewExists")


class ViewExistsViewExists(BaseModel):
    result: Optional[bool]


ViewExists.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class GetEmotion(BaseModel):
    emotion: Optional["GetEmotionEmotion"]


class GetEmotionEmotion(BaseModel):
    id: str
    name: str
    description: Optional[str]
    creation_date: Any = Field(alias="creationDate")
    feeds: Optional[list[Optional["GetEmotionEmotionFeeds"]]]


class GetEmotionEmotionFeeds(BaseModel):
    id: str
    name: str


GetEmotion.model_rebuild()
GetEmotionEmotion.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryGustoDepartments(BaseModel):
    gusto_departments: Optional["QueryGustoDepartmentsGustoDepartments"] = Field(
        alias="gustoDepartments"
    )


class QueryGustoDepartmentsGustoDepartments(BaseModel):
    results: Optional[list[Optional["QueryGustoDepartmentsGustoDepartmentsResults"]]]


class QueryGustoDepartmentsGustoDepartmentsResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]


QueryGustoDepartments.model_rebuild()
QueryGustoDepartmentsGustoDepartments.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateEmotion(BaseModel):
    update_emotion: Optional["UpdateEmotionUpdateEmotion"] = Field(
        alias="updateEmotion"
    )


class UpdateEmotionUpdateEmotion(BaseModel):
    id: str
    name: str


UpdateEmotion.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllLabels(BaseModel):
    delete_all_labels: Optional[list[Optional["DeleteAllLabelsDeleteAllLabels"]]] = (
        Field(alias="deleteAllLabels")
    )


class DeleteAllLabelsDeleteAllLabels(BaseModel):
    id: str
    state: EntityState


DeleteAllLabels.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityOwners, EntityState


class UpsertSkill(BaseModel):
    upsert_skill: Optional["UpsertSkillUpsertSkill"] = Field(alias="upsertSkill")


class UpsertSkillUpsertSkill(BaseModel):
    id: str
    name: str
    state: EntityState
    identifier: Optional[str]
    skill_owner: Optional[EntityOwners] = Field(alias="skillOwner")
    arguments: Optional[list["UpsertSkillUpsertSkillArguments"]]


class UpsertSkillUpsertSkillArguments(BaseModel):
    name: str
    description: Optional[str]
    required: Optional[bool]


UpsertSkill.model_rebuild()
UpsertSkillUpsertSkill.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class QueryOrganizationsClusters(BaseModel):
    organizations: Optional["QueryOrganizationsClustersOrganizations"]


class QueryOrganizationsClustersOrganizations(BaseModel):
    results: Optional[list[Optional["QueryOrganizationsClustersOrganizationsResults"]]]
    clusters: Optional["QueryOrganizationsClustersOrganizationsClusters"]


class QueryOrganizationsClustersOrganizationsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryOrganizationsClustersOrganizationsResultsOwner"
    state: EntityState
    alternate_names: Optional[list[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[
        list[Optional["QueryOrganizationsClustersOrganizationsResultsFeeds"]]
    ]
    links: Optional[
        list[Optional["QueryOrganizationsClustersOrganizationsResultsLinks"]]
    ]
    workflow: Optional["QueryOrganizationsClustersOrganizationsResultsWorkflow"]
    location: Optional["QueryOrganizationsClustersOrganizationsResultsLocation"]
    h_3: Optional["QueryOrganizationsClustersOrganizationsResultsH3"] = Field(
        alias="h3"
    )
    address: Optional["QueryOrganizationsClustersOrganizationsResultsAddress"]
    founding_date: Optional[Any] = Field(alias="foundingDate")
    email: Optional[str]
    telephone: Optional[str]
    legal_name: Optional[str] = Field(alias="legalName")
    industries: Optional[list[Optional[str]]]
    revenue: Optional[Any]
    revenue_currency: Optional[str] = Field(alias="revenueCurrency")
    investment: Optional[Any]
    investment_currency: Optional[str] = Field(alias="investmentCurrency")
    founders: Optional[
        list[Optional["QueryOrganizationsClustersOrganizationsResultsFounders"]]
    ]
    employees: Optional[
        list[Optional["QueryOrganizationsClustersOrganizationsResultsEmployees"]]
    ]
    members: Optional[
        list[Optional["QueryOrganizationsClustersOrganizationsResultsMembers"]]
    ]
    parent_organization: Optional[
        "QueryOrganizationsClustersOrganizationsResultsParentOrganization"
    ] = Field(alias="parentOrganization")
    member_of: Optional[
        list[Optional["QueryOrganizationsClustersOrganizationsResultsMemberOf"]]
    ] = Field(alias="memberOf")
    sub_organizations: Optional[
        list[Optional["QueryOrganizationsClustersOrganizationsResultsSubOrganizations"]]
    ] = Field(alias="subOrganizations")
    locations: Optional[
        list[Optional["QueryOrganizationsClustersOrganizationsResultsLocations"]]
    ]
    investments_received: Optional[
        list[
            Optional[
                "QueryOrganizationsClustersOrganizationsResultsInvestmentsReceived"
            ]
        ]
    ] = Field(alias="investmentsReceived")
    investor_funds: Optional[
        list[Optional["QueryOrganizationsClustersOrganizationsResultsInvestorFunds"]]
    ] = Field(alias="investorFunds")


class QueryOrganizationsClustersOrganizationsResultsOwner(BaseModel):
    id: str


class QueryOrganizationsClustersOrganizationsResultsFeeds(BaseModel):
    id: str
    name: str


class QueryOrganizationsClustersOrganizationsResultsLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class QueryOrganizationsClustersOrganizationsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryOrganizationsClustersOrganizationsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryOrganizationsClustersOrganizationsResultsH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class QueryOrganizationsClustersOrganizationsResultsAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


class QueryOrganizationsClustersOrganizationsResultsFounders(BaseModel):
    id: str
    name: str


class QueryOrganizationsClustersOrganizationsResultsEmployees(BaseModel):
    id: str
    name: str


class QueryOrganizationsClustersOrganizationsResultsMembers(BaseModel):
    id: str
    name: str


class QueryOrganizationsClustersOrganizationsResultsParentOrganization(BaseModel):
    id: str
    name: str


class QueryOrganizationsClustersOrganizationsResultsMemberOf(BaseModel):
    id: str
    name: str


class QueryOrganizationsClustersOrganizationsResultsSubOrganizations(BaseModel):
    id: str
    name: str


class QueryOrganizationsClustersOrganizationsResultsLocations(BaseModel):
    id: str
    name: str


class QueryOrganizationsClustersOrganizationsResultsInvestmentsReceived(BaseModel):
    id: str
    name: str


class QueryOrganizationsClustersOrganizationsResultsInvestorFunds(BaseModel):
    id: str
    name: str


class QueryOrganizationsClustersOrganizationsClusters(BaseModel):
    clusters: Optional[list["QueryOrganizationsClustersOrganizationsClustersClusters"]]


class QueryOrganizationsClustersOrganizationsClustersClusters(BaseModel):
    entities: list["QueryOrganizationsClustersOrganizationsClustersClustersEntities"]
    similarity: Optional[float]


class QueryOrganizationsClustersOrganizationsClustersClustersEntities(BaseModel):
    id: str
    name: Optional[str]


QueryOrganizationsClusters.model_rebuild()
QueryOrganizationsClustersOrganizations.model_rebuild()
QueryOrganizationsClustersOrganizationsResults.model_rebuild()
QueryOrganizationsClustersOrganizationsClusters.model_rebuild()
QueryOrganizationsClustersOrganizationsClustersClusters.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalContraindication(BaseModel):
    create_medical_contraindication: Optional[
        "CreateMedicalContraindicationCreateMedicalContraindication"
    ] = Field(alias="createMedicalContraindication")


class CreateMedicalContraindicationCreateMedicalContraindication(BaseModel):
    id: str
    name: str


CreateMedicalContraindication.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryBambooHRDivisions(BaseModel):
    bamboo_hr_divisions: Optional["QueryBambooHRDivisionsBambooHrDivisions"] = Field(
        alias="bambooHRDivisions"
    )


class QueryBambooHRDivisionsBambooHrDivisions(BaseModel):
    results: Optional[list[Optional["QueryBambooHRDivisionsBambooHrDivisionsResults"]]]


class QueryBambooHRDivisionsBambooHrDivisionsResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]


QueryBambooHRDivisions.model_rebuild()
QueryBambooHRDivisionsBambooHrDivisions.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    AgentChannelTypes,
    AgentTypes,
    ContentTypes,
    EntityState,
    FileTypes,
    TimedPolicyRecurrenceTypes,
)


class QueryAgents(BaseModel):
    agents: Optional["QueryAgentsAgents"]


class QueryAgentsAgents(BaseModel):
    results: Optional[list["QueryAgentsAgentsResults"]]


class QueryAgentsAgentsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryAgentsAgentsResultsOwner"
    state: EntityState
    correlation_id: Optional[str] = Field(alias="correlationId")
    type: AgentTypes
    specification: Optional["QueryAgentsAgentsResultsSpecification"]
    filter: Optional["QueryAgentsAgentsResultsFilter"]
    schedule_policy: Optional["QueryAgentsAgentsResultsSchedulePolicy"] = Field(
        alias="schedulePolicy"
    )
    channels: Optional[list["QueryAgentsAgentsResultsChannels"]]
    connectors: Optional[list["QueryAgentsAgentsResultsConnectors"]]
    timeout: Optional[Any]
    prompt: Optional[str]
    scratchpad: Optional[str]


class QueryAgentsAgentsResultsOwner(BaseModel):
    id: str


class QueryAgentsAgentsResultsSpecification(BaseModel):
    id: str


class QueryAgentsAgentsResultsFilter(BaseModel):
    types: Optional[list[ContentTypes]]
    file_types: Optional[list[FileTypes]] = Field(alias="fileTypes")
    feeds: Optional[list["QueryAgentsAgentsResultsFilterFeeds"]]


class QueryAgentsAgentsResultsFilterFeeds(BaseModel):
    id: str


class QueryAgentsAgentsResultsSchedulePolicy(BaseModel):
    recurrence_type: Optional[TimedPolicyRecurrenceTypes] = Field(
        alias="recurrenceType"
    )
    repeat_interval: Optional[Any] = Field(alias="repeatInterval")
    cron: Optional[str]
    time_zone_id: Optional[str] = Field(alias="timeZoneId")


class QueryAgentsAgentsResultsChannels(BaseModel):
    type: AgentChannelTypes
    identifier: str
    instructions: Optional[str]
    label: Optional[str]


class QueryAgentsAgentsResultsConnectors(BaseModel):
    id: str


QueryAgents.model_rebuild()
QueryAgentsAgents.model_rebuild()
QueryAgentsAgentsResults.model_rebuild()
QueryAgentsAgentsResultsFilter.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalCondition(BaseModel):
    update_medical_condition: Optional[
        "UpdateMedicalConditionUpdateMedicalCondition"
    ] = Field(alias="updateMedicalCondition")


class UpdateMedicalConditionUpdateMedicalCondition(BaseModel):
    id: str
    name: str


UpdateMedicalCondition.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryAtlassianSites(BaseModel):
    atlassian_sites: Optional["QueryAtlassianSitesAtlassianSites"] = Field(
        alias="atlassianSites"
    )


class QueryAtlassianSitesAtlassianSites(BaseModel):
    results: Optional[list[Optional["QueryAtlassianSitesAtlassianSitesResults"]]]


class QueryAtlassianSitesAtlassianSitesResults(BaseModel):
    identifier: Optional[str]
    name: Optional[str]
    url: Optional[str]


QueryAtlassianSites.model_rebuild()
QueryAtlassianSitesAtlassianSites.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryGustoLocations(BaseModel):
    gusto_locations: Optional["QueryGustoLocationsGustoLocations"] = Field(
        alias="gustoLocations"
    )


class QueryGustoLocationsGustoLocations(BaseModel):
    results: Optional[list[Optional["QueryGustoLocationsGustoLocationsResults"]]]


class QueryGustoLocationsGustoLocationsResults(BaseModel):
    identifier: Optional[str]
    street_1: Optional[str] = Field(alias="street1")
    street_2: Optional[str] = Field(alias="street2")
    city: Optional[str]
    state: Optional[str]
    zip: Optional[str]
    country: Optional[str]


QueryGustoLocations.model_rebuild()
QueryGustoLocationsGustoLocations.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityOwners, EntityState


class QuerySkills(BaseModel):
    skills: Optional["QuerySkillsSkills"]


class QuerySkillsSkills(BaseModel):
    results: Optional[list["QuerySkillsSkillsResults"]]


class QuerySkillsSkillsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QuerySkillsSkillsResultsOwner"
    state: EntityState
    identifier: Optional[str]
    correlation_id: Optional[str] = Field(alias="correlationId")
    text: str
    skill_owner: Optional[EntityOwners] = Field(alias="skillOwner")
    arguments: Optional[list["QuerySkillsSkillsResultsArguments"]]
    collections: Optional[list[Optional["QuerySkillsSkillsResultsCollections"]]]


class QuerySkillsSkillsResultsOwner(BaseModel):
    id: str


class QuerySkillsSkillsResultsArguments(BaseModel):
    name: str
    description: Optional[str]
    required: Optional[bool]


class QuerySkillsSkillsResultsCollections(BaseModel):
    id: str
    name: str


QuerySkills.model_rebuild()
QuerySkillsSkills.model_rebuild()
QuerySkillsSkillsResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DistributionServiceTypes


class UpdateNotionPage(BaseModel):
    update_notion_page: Optional["UpdateNotionPageUpdateNotionPage"] = Field(
        alias="updateNotionPage"
    )


class UpdateNotionPageUpdateNotionPage(BaseModel):
    identifier: Optional[str]
    uri: Optional[str]
    service_type: Optional[DistributionServiceTypes] = Field(alias="serviceType")


UpdateNotionPage.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ContentTypes,
    ConversationTypes,
    EntityState,
    FileTypes,
    FilterMode,
    ObservableTypes,
)


class QueryConversationsClusters(BaseModel):
    conversations: Optional["QueryConversationsClustersConversations"]


class QueryConversationsClustersConversations(BaseModel):
    results: Optional[list["QueryConversationsClustersConversationsResults"]]
    clusters: Optional[
        list[Optional["QueryConversationsClustersConversationsClusters"]]
    ]


class QueryConversationsClustersConversationsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryConversationsClustersConversationsResultsOwner"
    state: EntityState
    correlation_id: Optional[str] = Field(alias="correlationId")
    type: Optional[ConversationTypes]
    transcript_uri: Optional[Any] = Field(alias="transcriptUri")
    message_count: Optional[int] = Field(alias="messageCount")
    turn_count: Optional[int] = Field(alias="turnCount")
    agent: Optional["QueryConversationsClustersConversationsResultsAgent"]
    persona: Optional["QueryConversationsClustersConversationsResultsPersona"]
    specification: Optional[
        "QueryConversationsClustersConversationsResultsSpecification"
    ]
    fallbacks: Optional[
        list[Optional["QueryConversationsClustersConversationsResultsFallbacks"]]
    ]
    filter: Optional["QueryConversationsClustersConversationsResultsFilter"]
    augmented_filter: Optional[
        "QueryConversationsClustersConversationsResultsAugmentedFilter"
    ] = Field(alias="augmentedFilter")
    summary: Optional[str]


class QueryConversationsClustersConversationsResultsOwner(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsAgent(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsPersona(BaseModel):
    id: str
    name: str


class QueryConversationsClustersConversationsResultsSpecification(BaseModel):
    id: str
    name: str


class QueryConversationsClustersConversationsResultsFallbacks(BaseModel):
    id: str
    name: str


class QueryConversationsClustersConversationsResultsFilter(BaseModel):
    date_range: Optional[
        "QueryConversationsClustersConversationsResultsFilterDateRange"
    ] = Field(alias="dateRange")
    in_last: Optional[Any] = Field(alias="inLast")
    in_next: Optional[Any] = Field(alias="inNext")
    creation_date_range: Optional[
        "QueryConversationsClustersConversationsResultsFilterCreationDateRange"
    ] = Field(alias="creationDateRange")
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[list[ContentTypes]]
    file_types: Optional[list[FileTypes]] = Field(alias="fileTypes")
    formats: Optional[list[str]]
    file_extensions: Optional[list[str]] = Field(alias="fileExtensions")
    file_size_range: Optional[
        "QueryConversationsClustersConversationsResultsFilterFileSizeRange"
    ] = Field(alias="fileSizeRange")
    similar_contents: Optional[
        list["QueryConversationsClustersConversationsResultsFilterSimilarContents"]
    ] = Field(alias="similarContents")
    contents: Optional[
        list["QueryConversationsClustersConversationsResultsFilterContents"]
    ]
    feeds: Optional[list["QueryConversationsClustersConversationsResultsFilterFeeds"]]
    workflows: Optional[
        list["QueryConversationsClustersConversationsResultsFilterWorkflows"]
    ]
    collections: Optional[
        list["QueryConversationsClustersConversationsResultsFilterCollections"]
    ]
    users: Optional[list["QueryConversationsClustersConversationsResultsFilterUsers"]]
    observations: Optional[
        list["QueryConversationsClustersConversationsResultsFilterObservations"]
    ]
    or_: Optional[list["QueryConversationsClustersConversationsResultsFilterOr"]] = (
        Field(alias="or")
    )
    and_: Optional[list["QueryConversationsClustersConversationsResultsFilterAnd"]] = (
        Field(alias="and")
    )
    has_observations: Optional[bool] = Field(alias="hasObservations")
    has_feeds: Optional[bool] = Field(alias="hasFeeds")
    has_collections: Optional[bool] = Field(alias="hasCollections")
    has_workflows: Optional[bool] = Field(alias="hasWorkflows")
    collection_mode: Optional[FilterMode] = Field(alias="collectionMode")
    observation_mode: Optional[FilterMode] = Field(alias="observationMode")


class QueryConversationsClustersConversationsResultsFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsClustersConversationsResultsFilterCreationDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsClustersConversationsResultsFilterFileSizeRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsClustersConversationsResultsFilterSimilarContents(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsFilterContents(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsFilterFeeds(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsFilterWorkflows(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsFilterCollections(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsFilterUsers(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsFilterObservations(BaseModel):
    type: ObservableTypes
    observable: (
        "QueryConversationsClustersConversationsResultsFilterObservationsObservable"
    )
    states: Optional[list[EntityState]]


class QueryConversationsClustersConversationsResultsFilterObservationsObservable(
    BaseModel
):
    id: str


class QueryConversationsClustersConversationsResultsFilterOr(BaseModel):
    feeds: Optional[list["QueryConversationsClustersConversationsResultsFilterOrFeeds"]]
    workflows: Optional[
        list["QueryConversationsClustersConversationsResultsFilterOrWorkflows"]
    ]
    collections: Optional[
        list["QueryConversationsClustersConversationsResultsFilterOrCollections"]
    ]
    users: Optional[list["QueryConversationsClustersConversationsResultsFilterOrUsers"]]
    observations: Optional[
        list["QueryConversationsClustersConversationsResultsFilterOrObservations"]
    ]


class QueryConversationsClustersConversationsResultsFilterOrFeeds(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsFilterOrWorkflows(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsFilterOrCollections(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsFilterOrUsers(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsFilterOrObservations(BaseModel):
    type: ObservableTypes
    observable: (
        "QueryConversationsClustersConversationsResultsFilterOrObservationsObservable"
    )
    states: Optional[list[EntityState]]


class QueryConversationsClustersConversationsResultsFilterOrObservationsObservable(
    BaseModel
):
    id: str


class QueryConversationsClustersConversationsResultsFilterAnd(BaseModel):
    feeds: Optional[
        list["QueryConversationsClustersConversationsResultsFilterAndFeeds"]
    ]
    workflows: Optional[
        list["QueryConversationsClustersConversationsResultsFilterAndWorkflows"]
    ]
    collections: Optional[
        list["QueryConversationsClustersConversationsResultsFilterAndCollections"]
    ]
    users: Optional[
        list["QueryConversationsClustersConversationsResultsFilterAndUsers"]
    ]
    observations: Optional[
        list["QueryConversationsClustersConversationsResultsFilterAndObservations"]
    ]


class QueryConversationsClustersConversationsResultsFilterAndFeeds(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsFilterAndWorkflows(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsFilterAndCollections(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsFilterAndUsers(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsFilterAndObservations(BaseModel):
    type: ObservableTypes
    observable: (
        "QueryConversationsClustersConversationsResultsFilterAndObservationsObservable"
    )
    states: Optional[list[EntityState]]


class QueryConversationsClustersConversationsResultsFilterAndObservationsObservable(
    BaseModel
):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilter(BaseModel):
    date_range: Optional[
        "QueryConversationsClustersConversationsResultsAugmentedFilterDateRange"
    ] = Field(alias="dateRange")
    in_last: Optional[Any] = Field(alias="inLast")
    in_next: Optional[Any] = Field(alias="inNext")
    creation_date_range: Optional[
        "QueryConversationsClustersConversationsResultsAugmentedFilterCreationDateRange"
    ] = Field(alias="creationDateRange")
    created_in_last: Optional[Any] = Field(alias="createdInLast")
    types: Optional[list[ContentTypes]]
    file_types: Optional[list[FileTypes]] = Field(alias="fileTypes")
    formats: Optional[list[str]]
    file_extensions: Optional[list[str]] = Field(alias="fileExtensions")
    file_size_range: Optional[
        "QueryConversationsClustersConversationsResultsAugmentedFilterFileSizeRange"
    ] = Field(alias="fileSizeRange")
    similar_contents: Optional[
        list[
            "QueryConversationsClustersConversationsResultsAugmentedFilterSimilarContents"
        ]
    ] = Field(alias="similarContents")
    contents: Optional[
        list["QueryConversationsClustersConversationsResultsAugmentedFilterContents"]
    ]
    feeds: Optional[
        list["QueryConversationsClustersConversationsResultsAugmentedFilterFeeds"]
    ]
    workflows: Optional[
        list["QueryConversationsClustersConversationsResultsAugmentedFilterWorkflows"]
    ]
    collections: Optional[
        list["QueryConversationsClustersConversationsResultsAugmentedFilterCollections"]
    ]
    users: Optional[
        list["QueryConversationsClustersConversationsResultsAugmentedFilterUsers"]
    ]
    observations: Optional[
        list[
            "QueryConversationsClustersConversationsResultsAugmentedFilterObservations"
        ]
    ]
    or_: Optional[
        list["QueryConversationsClustersConversationsResultsAugmentedFilterOr"]
    ] = Field(alias="or")
    and_: Optional[
        list["QueryConversationsClustersConversationsResultsAugmentedFilterAnd"]
    ] = Field(alias="and")
    has_observations: Optional[bool] = Field(alias="hasObservations")
    has_feeds: Optional[bool] = Field(alias="hasFeeds")
    has_collections: Optional[bool] = Field(alias="hasCollections")
    has_workflows: Optional[bool] = Field(alias="hasWorkflows")
    collection_mode: Optional[FilterMode] = Field(alias="collectionMode")
    observation_mode: Optional[FilterMode] = Field(alias="observationMode")


class QueryConversationsClustersConversationsResultsAugmentedFilterDateRange(BaseModel):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsClustersConversationsResultsAugmentedFilterCreationDateRange(
    BaseModel
):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsClustersConversationsResultsAugmentedFilterFileSizeRange(
    BaseModel
):
    from_: Optional[Any] = Field(alias="from")
    to: Optional[Any]


class QueryConversationsClustersConversationsResultsAugmentedFilterSimilarContents(
    BaseModel
):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterContents(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterFeeds(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterWorkflows(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterCollections(
    BaseModel
):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterUsers(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterObservations(
    BaseModel
):
    type: ObservableTypes
    observable: "QueryConversationsClustersConversationsResultsAugmentedFilterObservationsObservable"
    states: Optional[list[EntityState]]


class QueryConversationsClustersConversationsResultsAugmentedFilterObservationsObservable(
    BaseModel
):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterOr(BaseModel):
    feeds: Optional[
        list["QueryConversationsClustersConversationsResultsAugmentedFilterOrFeeds"]
    ]
    workflows: Optional[
        list["QueryConversationsClustersConversationsResultsAugmentedFilterOrWorkflows"]
    ]
    collections: Optional[
        list[
            "QueryConversationsClustersConversationsResultsAugmentedFilterOrCollections"
        ]
    ]
    users: Optional[
        list["QueryConversationsClustersConversationsResultsAugmentedFilterOrUsers"]
    ]
    observations: Optional[
        list[
            "QueryConversationsClustersConversationsResultsAugmentedFilterOrObservations"
        ]
    ]


class QueryConversationsClustersConversationsResultsAugmentedFilterOrFeeds(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterOrWorkflows(
    BaseModel
):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterOrCollections(
    BaseModel
):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterOrUsers(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterOrObservations(
    BaseModel
):
    type: ObservableTypes
    observable: "QueryConversationsClustersConversationsResultsAugmentedFilterOrObservationsObservable"
    states: Optional[list[EntityState]]


class QueryConversationsClustersConversationsResultsAugmentedFilterOrObservationsObservable(
    BaseModel
):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterAnd(BaseModel):
    feeds: Optional[
        list["QueryConversationsClustersConversationsResultsAugmentedFilterAndFeeds"]
    ]
    workflows: Optional[
        list[
            "QueryConversationsClustersConversationsResultsAugmentedFilterAndWorkflows"
        ]
    ]
    collections: Optional[
        list[
            "QueryConversationsClustersConversationsResultsAugmentedFilterAndCollections"
        ]
    ]
    users: Optional[
        list["QueryConversationsClustersConversationsResultsAugmentedFilterAndUsers"]
    ]
    observations: Optional[
        list[
            "QueryConversationsClustersConversationsResultsAugmentedFilterAndObservations"
        ]
    ]


class QueryConversationsClustersConversationsResultsAugmentedFilterAndFeeds(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterAndWorkflows(
    BaseModel
):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterAndCollections(
    BaseModel
):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterAndUsers(BaseModel):
    id: str


class QueryConversationsClustersConversationsResultsAugmentedFilterAndObservations(
    BaseModel
):
    type: ObservableTypes
    observable: "QueryConversationsClustersConversationsResultsAugmentedFilterAndObservationsObservable"
    states: Optional[list[EntityState]]


class QueryConversationsClustersConversationsResultsAugmentedFilterAndObservationsObservable(
    BaseModel
):
    id: str


class QueryConversationsClustersConversationsClusters(BaseModel):
    entities: list["QueryConversationsClustersConversationsClustersEntities"]
    similarity: Optional[float]


class QueryConversationsClustersConversationsClustersEntities(BaseModel):
    id: str
    name: Optional[str]


QueryConversationsClusters.model_rebuild()
QueryConversationsClustersConversations.model_rebuild()
QueryConversationsClustersConversationsResults.model_rebuild()
QueryConversationsClustersConversationsResultsFilter.model_rebuild()
QueryConversationsClustersConversationsResultsFilterObservations.model_rebuild()
QueryConversationsClustersConversationsResultsFilterOr.model_rebuild()
QueryConversationsClustersConversationsResultsFilterOrObservations.model_rebuild()
QueryConversationsClustersConversationsResultsFilterAnd.model_rebuild()
QueryConversationsClustersConversationsResultsFilterAndObservations.model_rebuild()
QueryConversationsClustersConversationsResultsAugmentedFilter.model_rebuild()
QueryConversationsClustersConversationsResultsAugmentedFilterObservations.model_rebuild()
QueryConversationsClustersConversationsResultsAugmentedFilterOr.model_rebuild()
QueryConversationsClustersConversationsResultsAugmentedFilterOrObservations.model_rebuild()
QueryConversationsClustersConversationsResultsAugmentedFilterAnd.model_rebuild()
QueryConversationsClustersConversationsResultsAugmentedFilterAndObservations.model_rebuild()
QueryConversationsClustersConversationsClusters.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryBambooHRLocations(BaseModel):
    bamboo_hr_locations: Optional["QueryBambooHRLocationsBambooHrLocations"] = Field(
        alias="bambooHRLocations"
    )


class QueryBambooHRLocationsBambooHrLocations(BaseModel):
    results: Optional[list[Optional["QueryBambooHRLocationsBambooHrLocationsResults"]]]


class QueryBambooHRLocationsBambooHrLocationsResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]


QueryBambooHRLocations.model_rebuild()
QueryBambooHRLocationsBambooHrLocations.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteFeeds(BaseModel):
    delete_feeds: Optional[list[Optional["DeleteFeedsDeleteFeeds"]]] = Field(
        alias="deleteFeeds"
    )


class DeleteFeedsDeleteFeeds(BaseModel):
    id: str
    state: EntityState


DeleteFeeds.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DistributionServiceTypes


class DistributeContents(BaseModel):
    distribute_contents: Optional[list["DistributeContentsDistributeContents"]] = Field(
        alias="distributeContents"
    )


class DistributeContentsDistributeContents(BaseModel):
    uri: Optional[str]
    identifier: Optional[str]
    service_type: Optional[DistributionServiceTypes] = Field(alias="serviceType")
    error: Optional[str]


DistributeContents.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QueryBambooHREmploymentStatuses(BaseModel):
    bamboo_hr_employment_statuses: Optional[
        "QueryBambooHREmploymentStatusesBambooHrEmploymentStatuses"
    ] = Field(alias="bambooHREmploymentStatuses")


class QueryBambooHREmploymentStatusesBambooHrEmploymentStatuses(BaseModel):
    results: Optional[
        list[
            Optional["QueryBambooHREmploymentStatusesBambooHrEmploymentStatusesResults"]
        ]
    ]


class QueryBambooHREmploymentStatusesBambooHrEmploymentStatusesResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]


QueryBambooHREmploymentStatuses.model_rebuild()
QueryBambooHREmploymentStatusesBambooHrEmploymentStatuses.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DistributionServiceTypes


class Distribute(BaseModel):
    distribute: Optional[list["DistributeDistribute"]]


class DistributeDistribute(BaseModel):
    uri: Optional[str]
    identifier: Optional[str]
    service_type: Optional[DistributionServiceTypes] = Field(alias="serviceType")
    error: Optional[str]


Distribute.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteEmotion(BaseModel):
    delete_emotion: Optional["DeleteEmotionDeleteEmotion"] = Field(
        alias="deleteEmotion"
    )


class DeleteEmotionDeleteEmotion(BaseModel):
    id: str
    state: EntityState


DeleteEmotion.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class QuerySharePointLibraries(BaseModel):
    share_point_libraries: Optional["QuerySharePointLibrariesSharePointLibraries"] = (
        Field(alias="sharePointLibraries")
    )


class QuerySharePointLibrariesSharePointLibraries(BaseModel):
    account_name: Optional[str] = Field(alias="accountName")
    results: Optional[
        list[Optional["QuerySharePointLibrariesSharePointLibrariesResults"]]
    ]


class QuerySharePointLibrariesSharePointLibrariesResults(BaseModel):
    library_name: Optional[str] = Field(alias="libraryName")
    library_id: Optional[str] = Field(alias="libraryId")
    site_name: Optional[str] = Field(alias="siteName")
    site_id: Optional[str] = Field(alias="siteId")


QuerySharePointLibraries.model_rebuild()
QuerySharePointLibrariesSharePointLibraries.model_rebuild()
